* **************************************************************************** *
* **************************************************************************** *
* Breadwinners and Caregivers: Examining the Global Relationship between       *
* Gender Norms and Economic Behavior                                           *
* Replication File                                                             *
* PART 3: Master Dofile for Data Analysis                                      *
* 2024                                                                         *
* **************************************************************************** *
* **************************************************************************** *
/*
* Author: Paula Gonzalez
* Program Purpose: This master dofile orchestrates the replication analysis for 
*                  "Breadwinners and Caregivers: Examining the Global 
*                  Relationship between Gender Norms and Economic Behavior."
* Description:     This file executes the main and appendix analyses by invoking
*                  respective sub-dofiles. It ensures a streamlined and consistent
*                   analysis process.
* Date Last Reviewed: January 2024
*------------------------------------------------------------------------------*
* Datasets Required: 
* - Data 1 GenderAtHome_DataAnalysisInd: Data ready for analysis at individual level
* - Data 2 GenderAtHome_DataAnalysisCountry: Data ready for analysis collapse at 
                                             the country level 
* Outline: 
*  - Part 1: Preparation and Main Settings
*  - Part 2: Main Analysis Execution
*  - Part 3: Appendix Analysis Execution
*/

********************************************************************************
*                       PREPARATION AND MAIN SETTINGS 
********************************************************************************
if 1{
* ------------------------------------------------------------------------------
*  Define Sections to Execute:
*  - Set '1' to execute a section, '0' to skip it.
* ------------------------------------------------------------------------------
   local paper_name "BreadwinnersAndCaregivers"    
   local MainAnalysis     0 // Set to 1 to execute main analysis
   local AppendixAnalysis 1  // Set to 1 to execute appendix analysis
   
* Set scheme and font for all graphs 
  set scheme white_tableau
  graph set window fontface "Times New Roman"  
     
}   

********************************************************************************
*                     MAIN ANALYSIS EXECUTION
******************************************************************************** 
if (`MainAnalysis' == 1) {

*** ======================================================================== ***
*   Table 1: Sample Characteristics by Respondent Gender 
*** ======================================================================== ***
    do "$dofiles/Analysis/Sections/DS_SampleCharacteristics.do"
 
*** ======================================================================== ***
*   Figure 1: Gender Gaps in Personal Beliefs and Perceived Community Norms by Region 
*** ======================================================================== ***
    do "$dofiles/Analysis/Sections/Fig_GenderGapNormsRegion.do"
	
*** ======================================================================== ***
*   Figure 2,3 and 4: Country Level Gender Norms  
*** ======================================================================== ***
    do "$dofiles/Analysis/Sections/Fig_NormsCountryLevel.do"

*** ======================================================================== ***
*   Maps 5, 6 and 7
*** ======================================================================== ***
    do "$dofiles/Analysis/Sections/Fig_MapsMisperception.do"
	
*** ======================================================================== ***
*   Regression Analysis 
*** ======================================================================== ***
    do "$dofiles/Analysis/Sections/Regressions_LaborAndNorms.do"
    do "$dofiles/Analysis/Sections/Regressions_DecisionMakingAndNorms.do"
    do "$dofiles/Analysis/Sections/Regressions_CareDomesticRespAndNorms.do"	
	
} 

********************************************************************************
*                    APPENDIX ANALYSIS EXECUTION
******************************************************************************** 
if (`AppendixAnalysis' == 1) {
*** ======================================================================== ***
*   A3. Descriptive Statistics of Main Variables by Gender
*** ======================================================================== *** 
    do "$dofiles/Analysis/Sections/Appendix/DS_MainVarGender.do"

*** ======================================================================== ***
*   A4-A5 Correlation of the Female Caregiver Norm and Male Breadwinner Norm 
*   with World Values Survey (WVS)
*** ======================================================================== *** 
    do "$dofiles/Analysis/Sections/Appendix/DS_ComparissonWVS.do"

*** ======================================================================== ***
*   A6: Correlation of the Broad Norm with the Gallup World Poll Measure
*** ======================================================================== *** 
    do "$dofiles/Analysis/Sections/Appendix/DS_CorrBroadNormGallup.do"

*** ======================================================================== ***
*  A7 - A9: Data for all Regions: East Asia Pacific (EAP),  Europe Central Asia (ECA),
*  Latin America and the Caribbean (LAC),  Middle East and North Africa (MENA), 
*  North America, South Asia and Sub Saharan Africa (SSA). 
*** ======================================================================== ***  
    do "$dofiles/Analysis/Sections/Appendix/DS_DataByRegions.do"
   
*** ======================================================================== ***
*   A10: Gender Differences in Average Personal Beliefs and Norms by Region of the World
*** ======================================================================== *** 
    do "$dofiles/Analysis/Sections/Appendix/DS_GenderDiffRegion.do"

*** ======================================================================== ***
*   Figure B1-B3: Personal Beliefs and Perceived Norms Split by Gender
*** ======================================================================== *** 
    do "$dofiles/Analysis/Sections/Appendix/Fig_BeliefsAndNormsSplitGender.do"

*** ======================================================================== ***
*   Figure C1-C3:Gender Beliefs and Macroeconomic Indicators
*** ======================================================================== *** 
    do "$dofiles/Analysis/Sections/Appendix/Fig_GenderBeliefMacro.do" 
   
*** ======================================================================== ***
*   Figure D1-D3: Gender Differences in Misperceptions of Norms (kdensity)
*** ======================================================================== *** 
    do "$dofiles/Analysis/Sections/Appendix/Fig_GenDiffMispNorm.do"

*** ======================================================================== ***
*   Table D1: The Degree of Norm Misperception by Gender across Regions of the World
*** ======================================================================== *** 
    do "$dofiles/Analysis/Sections/Appendix/DS_DegreeMisperceptionRegion.do"
   
*** ======================================================================== ***
*   Table D2: Correlates of Norm Miscperceptions
*** ======================================================================== *** 
    do "$dofiles/Analysis/Sections/Appendix/Reg_NormMisperception.do"

} 
******************************************************************************** 
/// END OF DOFILE