*** ======================================================================== ***
*  A7 - A9: Data for all Regions: East Asia Pacific (EAP),  Europe Central Asia (ECA),
*** ======================================================================== ***
/* Description: This dofile export the table that compares the G */

* Loading Dataset at the Country Level 
  use "$data/Final/GenderAtHome_DataAnalysisCountry.dta", clear 

* Keeping sample of countries that merge our dataset with WVS
  keep if wvs_merge==1
  # d;
  gl  var_norms  code_iso3
                 woman_role_mal D0610   diff_femcare_mal 
                 woman_role_fem D0611   diff_femcare_fem
				  
				 expens_fem     D0661   diff_malbred_mal    
				 expens_mal     D0660   diff_malbred_fem;
  # d cr; 				 

 * Ordering variables
   order $var_norms
   keep  $var_norms
   sort code_iso3
   
 * Setting up globals by category 
   gl female_care woman_role_mal D0610   diff_femcare_mal                       ///
                  woman_role_fem D0611   diff_femcare_fem
				  
   gl male_breadw expens_mal     D0660  diff_malbred_mal                       ///
				  expens_fem     D0661  diff_malbred_fem				  
 
 * Rounding difference in ranking 
  gl  var_norms  woman_role_fem     woman_role_mal    D0610 D0611     ///
				   expens_fem         expens_mal        D0660 D0661     ///
				   diff_femcare_fem   diff_femcare_mal               ///
				   diff_malbred_fem   diff_malbred_mal	
  foreach var of varlist $var_norms {
    replace `var'= round(`var')
  }  
     
 
 * Generating an average row to export 
 // Increase the number of observations by 1
 // Add a new observation for total 
	expand 2 if _n == _N
	replace code_iso3 ="Average Absolute value" in L
	
    foreach var of varlist $var_norms {
    replace `var'=. if  code_iso3=="Average Absolute value"
    }  
** Female Care variable 
// Create a temporary variable for the absolute value Female
   gen     abs_diff_femcare_fem = abs(diff_femcare_fem)
   sum     abs_diff_femcare_fem, meanonly
   local   mean_value1 = r(mean)   
   replace diff_femcare_fem=`mean_value1'  if code_iso3=="Average Absolute value"
   
// Create a temporary variable for the absolute value Male
   gen     abs_diff_femcare_mal = abs(diff_femcare_mal)
   sum     abs_diff_femcare_mal, meanonly
   local   mean_value1 = r(mean)   
   replace diff_femcare_mal=`mean_value1'  if code_iso3=="Average Absolute value"
 

** Male Breadwinner variable 
// Create a temporary variable for the absolute value
   gen     abs_diff_malbred_fem= abs(diff_malbred_fem)
   sum     abs_diff_malbred_fem, meanonly
   local   mean_value1 = r(mean)   
   replace diff_malbred_fem=`mean_value1'  if code_iso3=="Average Absolute value"
   
// Create a temporary variable for the absolute value
   gen     abs_diff_malbred_mal = abs(diff_malbred_mal)
   sum     abs_diff_malbred_mal, meanonly
   local   mean_value1 = r(mean)   
   replace diff_malbred_mal=`mean_value1'  if code_iso3=="Average Absolute value"
   
   drop abs_diff_femcare_fem abs_diff_femcare_mal ///
        abs_diff_malbred_mal abs_diff_malbred_mal  
   
  gl  var_norms    diff_femcare_fem   diff_femcare_mal               ///
				   diff_malbred_fem   diff_malbred_mal	
  foreach var of varlist $var_norms {
    replace `var'= round(`var', 0.05)  if code_iso3=="Average Absolute value"
  }  
     
   
** Export the dataset with female caregiver variables to Excel
** -----------------------------------------------------------------------------

  gl output_name   DS_FemaleCareWVS
  # d;
  export excel code_iso3 $female_care using 
              "$outputs_raw/Tables/Appendix/$output_name.xlsx",        
               firstrow(varlabels) replace;
  # d cr; 			   

** Exporting to unique file 
** ------------------------------------------	
    local svdate: di %tdCCYYNNDD daily("$S_DATE", "DMY")
    disp "`svdate'" 			   
	preserve 
	* Import table from csv
	import excel "$outputs_raw/Tables/Appendix/$output_name.xlsx", ///
	clear 

	* Exporting into common file 
	export excel using "$outputs_raw/Tables\GenderAtHome_AppendixTables_`svdate'.xlsx", ///
				 sheet("$output_name", modify) 
	restore   

  
  
  
** Export the dataset with male breadwinner variables to Excel
** -----------------------------------------------------------------------------
  gl output_name   DS_MaleBreadwinnerWVS
  # d;
  export excel code_iso3 $male_breadw using 
              "$outputs_raw/Tables/Appendix/$output_name.xlsx",        
               firstrow(varlabels) replace;
  # d cr; 
  
** Exporting to unique file 
** ------------------------------------------	
    local svdate: di %tdCCYYNNDD daily("$S_DATE", "DMY")
    disp "`svdate'" 			   
	preserve 
	* Import table from csv
	import excel "$outputs_raw/Tables/Appendix/$output_name.xlsx", ///
	clear 

	* Exporting into common file 
	export excel using "$outputs_raw/Tables\GenderAtHome_AppendixTables_`svdate'.xlsx", ///
				 sheet("$output_name", modify) 
	restore   

********************************************************************************
// END OF DOFILE 
 
  
  