*** ======================================================================== ***
*  A7 - A9: Data for all Regions: East Asia Pacific (EAP),  Europe Central Asia (ECA),
*  Latin America and the Caribbean (LAC),  Middle East and North Africa (MENA), 
*  North America, South Asia and Sub Saharan Africa (SSA). 
*** ======================================================================== ***
/* Description: This dofile export the data for the individual belief, 
   perceived norms and the grade of misperception at the country level. These
   set of variables are generated for the national population, 
   for women and for men and across the three norms. 
   Individual tables by region are generated to then be exported into 
   and  individual file.
   The individual files then need to be trasport in excel so variables 
   names are in columns while countires are in rows. */

* Loading Dataset at the Country Level 
  use "$data/Final/GenderAtHome_DataAnalysisCountry.dta", clear 

* Setting up globals  for variables we want to include country level data on 
  # d;  
  gl GenderAtHome d_eq_opport_agree_mn  
                  d_eq_opport_agree_fem
                  d_eq_opport_agree_mal  
				  est_eq_opport_neighb
				  eq_opport_neighb_fem
				  eq_opport_neighb_mal
				  pign_eq_opport2
				  pign_eq_opportwom2
				  pign_eq_opportmen2
				  
				  d_expens_agree_mn
				  d_expens_agree_fem
				  d_expens_agree_mal
				  est_expens_neigh
				  expens_neigh_fem 
				  expens_neigh_mal
				  pign_expens2
				  pign_expenswom2
				  pign_expensmen2
				  
				  d_woman_role_agree_mn
				  d_woman_role_agree_fem
				  d_woman_role_agree_mal
				  est_woman_role_neigh
				  woman_role_neigh_fem
				  woman_role_neigh_mal
				  pign_womanr2
				  pign_womanrwom2
				  pign_womanrmen2;
  # d cr;				 
  
	 
	 
* Descriptive Statistics by Region 
* ---------------------------------------------------------------------	 
  * Setting up global 
  gl DS_var $GenderAtHome

  * Code to export individual tables by region 
    foreach reg_code in 1 2 3 4 5 6 7 { 
    foreach reg_name in EAP ECA LAC MENA NorthAmerica SouthAsia SSA{
  	
	if ("`reg_code'" == "1" & ("`reg_name'" == "EAP" ))          |              ///
	   ("`reg_code'" == "2" & ("`reg_name'" == "ECA" ))          |              /// 
	   ("`reg_code'" == "3" & ("`reg_name'" == "LAC" ))          |              /// 
	   ("`reg_code'" == "4" & ("`reg_name'" == "MENA" ))         |              /// 
	   ("`reg_code'" == "5" & ("`reg_name'" == "NorthAmerica" )) |              ///
	   ("`reg_code'" == "6" & ("`reg_name'" == "SouthAsia" ))    |              ///
       ("`reg_code'" == "7" & ("`reg_name'" == "SSA" ))	 {	
	
  * Individual Tables by Region
	# d; 
	 eststo  clear;
	 estpost tabstat $DS_var if region==`reg_code', by(code_iso3)				             
			 statistics(mean) columns(statistics);
		
	 esttab using "$outputs_raw/Tables/Appendix/Data`reg_name'.csv", 	 
	 cells("mean(fmt(%9.2f)label (Mean))")
	 title("Table:Data by region `reg_name'") label 			
	 unstack  nonumbers nogaps nonote plain replace;
	# d cr; 	
	
** Exporting to unique file 
** ------------------------------------------	
    local svdate: di %tdCCYYNNDD daily("$S_DATE", "DMY")
    disp "`svdate'" 			   
	preserve 
	* Import table from csv
	import delimited "$outputs_raw/Tables/Appendix/Data`reg_name'.csv", ///
	clear delimiter(comma)

	* Exporting into common file 
	export excel using "$outputs_raw/Tables\GenderAtHome_AppendixTables_`svdate'.xlsx", ///
				 sheet("Data`reg_name'", modify) 
	restore   
  
	   }
	}
}
   
   