*** ======================================================================== ***
*   Figure B1-B3: Personal Beliefs and Perceived Norms Split by Gender
*** ======================================================================== ***
/* Description: This dofile should be run to create te figures b1 to b3 
                where we compare in a scatter plot individual belief with 
				community norms by gender.  */

				
* Loading Dataset at the Country Level 
  use "$data/Final/GenderAtHome_DataAnalysisCountry.dta", clear 

* Set scheme and font for all graphs 
  set scheme white_tableau
  graph set window fontface "Times New Roman"  
  
** =============================================================================
** Norm 1: Men and women shoudl have equal opportunities 
** =============================================================================
if 1{
* Female Respondents 
* -----------------------------------
if 1{
gl output_name GenderNorm1_Female	
gl outcome1   d_eq_opport_agree_fem
gl outcome2   eq_opport_neighb_fem
local y_title "Personal Beliefs (%)"
local x_title "Perceived Community Norm(%)" 

gl subtitle  "Female Respondents"

count if !missing($outcome1) 
local N `r(N)'

corr $outcome2 $outcome1
local r=round(r(rho),.01)
di `r'


# d;
twoway 
    (scatter $outcome1 $outcome2,
	mlab(code_iso3) mlabcolor("0 153 153") mlabsize(vsmall)
	msize(small) mcolor("147 112 219")msymbol(Oh))
	(line $outcome2 $outcome2, lcolor("147 112 219") lwidth(vthin)), 
	ytitle(`y_title', size(small)) 
	xtitle(`x_title', size(small))  
	ylabel(30(5)100,labsize (vsmall))  
	xlabel(30(5)100,labsize (vsmall))  
	legend(off) 
    //title("$title", justification(left) color(black) span pos(12) size(medium))
	bgcolor (white) graphregion(color(white))
	subtitle("$subtitle", justification(left) color(black) span pos(12) size(small))
	bgcolor (white) graphregion(color(white))
	note("Pearson's correlation coefficient:`r'", size(vsmall));	
# d cr;	

*Save graph 
graph save "$outputs_raw/Figures/Appendix/${output_name}.gph", replace
}

* Male Respondents 
* -----------------------------------
if 1{
gl output_name GenderNorm1_Male	
gl outcome1   d_eq_opport_agree_mal
gl outcome2   eq_opport_neighb_mal
local y_title "Personal Beliefs (%)"
local x_title "Perceived Community Norm(%)" 

gl subtitle  "Male Respondents"

count if !missing($outcome1) 
local N `r(N)'

corr $outcome2 $outcome1
local r=round(r(rho),.82)
di `r'


# d;
twoway 
    (scatter $outcome1 $outcome2,
	mlab(code_iso3) mlabcolor("0 153 153") mlabsize(vsmall)
	msize(small) mcolor("147 112 219")msymbol(Oh))
	(line $outcome2 $outcome2, lcolor("147 112 219") lwidth(vthin)), 
	ytitle(`y_title', size(small)) 
	xtitle(`x_title', size(small))  
	ylabel(30(5)100,labsize (vsmall))  
	xlabel(30(5)100,labsize (vsmall))  
	legend(off) 
    //title("$title", justification(left) color(black) span pos(12) size(medium))
	bgcolor (white) graphregion(color(white))
	subtitle("$subtitle", justification(left) color(black) span pos(12) size(small))
	bgcolor (white) graphregion(color(white))
	note("Pearson's correlation coefficient:`r'", size(vsmall));	
# d cr;	

*Save graph 
graph save "$outputs_raw/Figures/Appendix/${output_name}.gph", replace
}

* Graph combination 
* ---------------------------------------------------------------------------	
  gl title "Broad Norm: Men and women should have equal opportunities"
  gl subtitle "{it:Personal Beliefs and Perceived Community Norms Disaggregated by Gender}"
  gl output_name IndCom_GenderNorm1
 
 # d;	
  gr combine "$outputs_raw/Figures/Appendix/GenderNorm1_Female.gph"
			 "$outputs_raw/Figures/Appendix/GenderNorm1_Male.gph", 
				   graphregion(color(white)) 
				   title($title, size(small)  
                   color(dknavy) span pos(11))
				   subtitle($subtitle, size(vsmall) span pos(11))
				   note("Sample: `N' countries.", size(tiny))
				   row(1);
 # d cr;		
 
* Saving and exporting graph
  graph save  "$outputs_raw/Figures/Appendix/${output_name}.gph", replace		
  graph export "$outputs_raw/Figures/Appendix/${output_name}.png", as(png) width(1000) replace 	 
 
 

 }


** =============================================================================
** Norm 2: Expenses are man responsibility even if wife can help
** ============================================================================= 
 if 1{

* Female Respondents 
* -----------------------------------
if 1{
gl output_name GenderNorm2_Female	
gl outcome1   d_expens_agree_fem
gl outcome2   expens_neigh_fem 
local y_title "Personal Beliefs (%)"
local x_title "Perceived Community Norm(%)" 

gl subtitle  "Female Respondents"

count if !missing($outcome1) 
local N `r(N)'

corr $outcome2 $outcome1
local r=round(r(rho),.01)
di `r'


# d;
twoway 
    (scatter $outcome1 $outcome2,
	mlab(code_iso3) mlabcolor("0 153 153") mlabsize(vsmall)
	msize(small) mcolor("147 112 219")msymbol(Oh))
	(line $outcome2 $outcome2, lcolor("147 112 219") lwidth(vthin)), 
	ytitle(`y_title', size(small)) 
	xtitle(`x_title', size(small))  
	ylabel(5(5)95,labsize (vsmall))  
	xlabel(5(5)95,labsize (vsmall))  
	legend(off) 
    //title("$title", justification(left) color(black) span pos(12) size(medium))
	bgcolor (white) graphregion(color(white))
	subtitle("$subtitle", justification(left) color(black) span pos(12) size(small))
	bgcolor (white) graphregion(color(white))
	note("Pearson's correlation coefficient:`r'", size(vsmall));	
# d cr;	

*Save graph 
graph save "$outputs_raw/Figures/Appendix/${output_name}.gph", replace
}

* Male Respondents 
* -----------------------------------
if 1{
gl output_name GenderNorm2_Male	
gl outcome1   d_expens_agree_mal
gl outcome2   expens_neigh_mal
local y_title "Personal Beliefs (%)"
local x_title "Perceived Community Norm(%)" 

gl subtitle  "Male Respondents"

count if !missing($outcome1) 
local N `r(N)'

corr $outcome2 $outcome1
local r=round(r(rho),.82)
di `r'


# d;
twoway 
    (scatter $outcome1 $outcome2,
	mlab(code_iso3) mlabcolor("0 153 153") mlabsize(vsmall)
	msize(small) mcolor("147 112 219")msymbol(Oh))
	(line $outcome2 $outcome2, lcolor("147 112 219") lwidth(vthin)), 
	ytitle(`y_title', size(small)) 
	xtitle(`x_title', size(small))  
	ylabel(5(5)95,labsize (vsmall))  
	xlabel(5(5)95,labsize (vsmall))  
	legend(off) 
    //title("$title", justification(left) color(black) span pos(12) size(medium))
	bgcolor (white) graphregion(color(white))
	subtitle("$subtitle", justification(left) color(black) span pos(12) size(small))
	bgcolor (white) graphregion(color(white))
	note("Pearson's correlation coefficient:`r'", size(vsmall));	
# d cr;	

*Save graph 
graph save "$outputs_raw/Figures/Appendix/${output_name}.gph", replace
}

* Graph combination 
* ---------------------------------------------------------------------------	
  gl title "Breadwinner Norm: Expenses are a man's responsibility even if his wife can help him"
  gl subtitle "{it:Personal Beliefs and Perceived Community Norms Disaggregated by Gender}"
  gl output_name IndCom_GenderNorm2
 
 # d;	
  gr combine "$outputs_raw/Figures/Appendix/GenderNorm2_Female.gph"
			 "$outputs_raw/Figures/Appendix/GenderNorm2_Male.gph", 
				   graphregion(color(white)) 
				   title($title, size(small)  
                   color(dknavy) span pos(11))
				   subtitle($subtitle, size(vsmall) span pos(11))
				   note("Sample: `N' countries.", size(tiny))
				   row(1);
 # d cr;		
 
* Saving and exporting graph
  graph save  "$outputs_raw/Figures/Appendix/${output_name}.gph", replace		
  graph export "$outputs_raw/Figures/Appendix/${output_name}.png", as(png) width(1000) replace 	 
		 

 }

** =============================================================================
** Norm 3: Woman's most important role is care of home and child
** ============================================================================= 
 if 1{
* Female Respondents 
* -----------------------------------
if 1{
gl output_name GenderNorm3_Female	
gl outcome1    d_woman_role_agree_fem
gl outcome2    woman_role_neigh_fem 
local y_title "Personal Beliefs (%)"
local x_title "Perceived Community Norm(%)" 

gl subtitle  "Female Respondents"

count if !missing($outcome1) 
local N `r(N)'

corr $outcome2 $outcome1
local r=round(r(rho),.01)
di `r'


# d;
twoway 
    (scatter $outcome1 $outcome2,
	mlab(code_iso3) mlabcolor("0 153 153") mlabsize(vsmall)
	msize(small) mcolor("147 112 219")msymbol(Oh))
	(line $outcome2 $outcome2, lcolor("147 112 219") lwidth(vthin)), 
	ytitle(`y_title', size(small)) 
	xtitle(`x_title', size(small))  
	ylabel(5(5)95,labsize (vsmall))  
	xlabel(5(5)95,labsize (vsmall))  
	legend(off) 
    //title("$title", justification(left) color(black) span pos(12) size(medium))
	bgcolor (white) graphregion(color(white))
	subtitle("$subtitle", justification(left) color(black) span pos(12) size(small))
	bgcolor (white) graphregion(color(white))
	note("Pearson's correlation coefficient:`r'", size(vsmall));	
# d cr;	

*Save graph 
graph save "$outputs_raw/Figures/Appendix/${output_name}.gph", replace
}

* Male Respondents 
* -----------------------------------
if 1{
gl output_name GenderNorm3_Male	
gl outcome1    d_woman_role_agree_mal
gl outcome2    woman_role_neigh_mal 
local y_title "Personal Beliefs (%)"
local x_title "Perceived Community Norm(%)" 

gl subtitle  "Male Respondents"

count if !missing($outcome1) 
local N `r(N)'

corr $outcome2 $outcome1
local r=round(r(rho),.82)
di `r'


# d;
twoway 
    (scatter $outcome1 $outcome2,
	mlab(code_iso3) mlabcolor("0 153 153") mlabsize(vsmall)
	msize(small) mcolor("147 112 219")msymbol(Oh))
	(line $outcome2 $outcome2, lcolor("147 112 219") lwidth(vthin)), 
	ytitle(`y_title', size(small)) 
	xtitle(`x_title', size(small))  
	ylabel(5(5)95,labsize (vsmall))  
	xlabel(5(5)95,labsize (vsmall))  
	legend(off) 
    //title("$title", justification(left) color(black) span pos(12) size(medium))
	bgcolor (white) graphregion(color(white))
	subtitle("$subtitle", justification(left) color(black) span pos(12) size(small))
	bgcolor (white) graphregion(color(white))
	note("Pearson's correlation coefficient:`r'", size(vsmall));	
# d cr;	

*Save graph 
graph save "$outputs_raw/Figures/Appendix/${output_name}.gph", replace
}

* Graph combination 
* ---------------------------------------------------------------------------	
  gl title    "Caregiver Norm: Women's most important role is to take care of her home and children"
  gl subtitle "{it:Personal Beliefs and Perceived Community Norms Disaggregated by Gender}"
  gl output_name IndCom_GenderNorm3
 
 # d;	
  gr combine "$outputs_raw/Figures/Appendix/GenderNorm3_Female.gph"
			 "$outputs_raw/Figures/Appendix/GenderNorm3_Male.gph", 
				   graphregion(color(white)) 
				   title($title, size(small)  
                   color(dknavy) span pos(11))
				   subtitle($subtitle, size(vsmall) span pos(11))
				   note("Sample: `N' countries.", size(tiny))
				   row(1);
 # d cr;		
 
* Saving and exporting graph
  graph save   "$outputs_raw/Figures/Appendix/${output_name}.gph", replace		
  graph export "$outputs_raw/Figures/Appendix/${output_name}.png", as(png) width(1000) replace 	 
		
 }


******************************************************************************** 
/// END OF DOFILE

