*** ======================================================================== ***
* Figure C1-C3:Gender Beliefs and Macroeconomic Indicator
*** ======================================================================== ***
/* Description:*/

* Loading Dataset at the Country Level 
  use "$data/Final/GenderAtHome_DataAnalysisCountry.dta", clear 
  
* Set scheme and font for all graphs 
  set scheme white_tableau
  graph set window fontface "Times New Roman"  
   
  
* We multiply for 10 for redability 
  replace  d_eq_opport_agree=d_eq_opport_agree*10
  replace  d_expens_agree= d_expens_agree*10
  replace  d_woman_role_agree=d_woman_role_agree*10 
  
* Sorting
  sort ln_gdp_usd
  sort  WBLINDEX  
  
** =============================================================================
** Norm 1: Men and women shoudl have equal opportunities  (Format 1)
** =============================================================================	
if 1{	
* Individual Norm Female male with GDP 
* ------------------------------------------------------------------------------
if 1{
  gl outcome1a d_eq_opport_agree_fem 
  gl outcome1b d_eq_opport_agree_mal
  gl outcome2  ln_gdp_usd
  local vary   gdp4
  
** Mean of variable by gender  
 foreach quarter in 1 2 3 4{
  * Female
  local var $outcome1a
  gen       `var'_q`quarter'=`var' if `vary'==`quarter'
  mean      `var'_q`quarter' 
  estimates store mnf_var_q`quarter'
  drop `var'_q`quarter'
   
  * Male 
  local var $outcome1b
  gen       `var'_q`quarter'=`var' if `vary'==`quarter'
  mean      `var'_q`quarter' 
  estimates store mnm_var_q`quarter'
  drop `var'_q`quarter'
 }
  
 * Correlation by gender  
  corr      $outcome1a  $outcome2 
  local     corrf=round(r(rho),.01)
 
  corr      $outcome1b $outcome2
  local     corrm=round(r(rho),.01)

  
** Setting up graph code: 
    gl out_name "GDPNorm1"
	gl subtitle "Personal Beliefs and GDP" 
	
	local ytitle "Personal Beliefs (%)"
	local xtitle "GDP by quarter"
	
    local var1 $outcome1a
	local var2 $outcome1b
    local lc1  barwidth(0.31) color(none) lcolor("147 112 219") ///
	           ciopts(lcolor("purple%40")  recast(rcap) lwidth(vthin))
	local lc2  barwidth(0.27)  color(white) lcolor("0 153 153") ///
	           ciopts(lcolor("emerald%40") recast(rcap) lwidth(vthin))
	
* Code for graph 
  # d ;
  coefplot  (mnf_var_q1, rename(`var1'_q1="Q1") recast(bar) `lc1') 
			(mnm_var_q1, rename(`var2'_q1="Q1") recast(bar) `lc2')
			
            (mnf_var_q2, rename(`var1'_q2="Q2") recast(bar) `lc1') 
			(mnm_var_q2, rename(`var2'_q2="Q2") recast(bar) `lc2')
			
            (mnf_var_q3, rename(`var1'_q3="Q3") recast(bar) `lc1') 
			(mnm_var_q3, rename(`var2'_q3="Q3") recast(bar) `lc2')			
			
			(mnf_var_q4, rename(`var1'_q4="Q4") recast(bar) `lc1') 
			(mnm_var_q4, rename(`var2'_q4="Q4") recast(bar) `lc2'),
			 ciopts(recast(rcap) lcolor(gs7))  citop 
			 vertical nooffsets    format(%9.2f) 
			 addplot(scatter @b @at, ms(i) mlabel(@b) mlabpos(11) mlabcolor(black) mlabsize(vsmall))
			 plotregion(margin(b=0))
			 legend(order( 1 "Mean Female" 3 "Mean Male") row(1) pos(6)
			        size(vsmall)  symxsize(2) region(lstyle(none))) 
	         subtitle($subtitle, size(small) color("0 51 102") 
				        justification(left) pos(11))
			 ytitle(`ytitle', size(vsmall)) ylabel(70(10)100,labsize (vsmall)) 
			 xtitle(`xtitle', size(vsmall)) xlabel (,labsize (vsmall)) xlabel(, angle(360)) 
			 graphregion(color(none))
			 note("Rho:`corrf' is the overall correlation between female personal beliefs and GDP per capita"
                  "Rho:`corrm' is the overall correlation between male personal beliefs and GDP per capita".
				  , size (vsmall));
		# d cr; 	 
	
  * Saving Graph 
	graph save "$outputs_raw/Figures/Appendix/$out_name.gph", replace	
	
}	

* Individual Norm Female male with FLP
* ------------------------------------------------------------------------------	
if 1{
  gl outcome1a d_eq_opport_agree_fem 
  gl outcome1b d_eq_opport_agree_mal
  gl outcome2  sl_tlf_cact_fe_zs
  local vary      LFP4
  
** Mean of variable by gender  
 foreach quarter in 1 2 3 4{
  * Female
  local var $outcome1a
  gen       `var'_q`quarter'=`var' if `vary'==`quarter'
  mean      `var'_q`quarter' 
  estimates store mnf_var_q`quarter'
  drop `var'_q`quarter'
   
  local var $outcome1b
  gen       `var'_q`quarter'=`var' if `vary'==`quarter'
  mean      `var'_q`quarter' 
  estimates store mnm_var_q`quarter'
  drop `var'_q`quarter'
 }
  

 * Correlation by gender  
  corr      $outcome1a  $outcome2 
  local     corrf=round(r(rho),.01)
 
  corr      $outcome1b $outcome2
  local     corrm=round(r(rho),.01)
  
** Setting up graph code: 
    gl out_name "LFPNorm1"
	gl subtitle "Personal Beliefs and Female Labor Force Participation" 
	
	local ytitle "Personal Beliefs(%)"
	local xtitle "FLFP (%)"
    local var1 $outcome1a
	local var2 $outcome1b
    local lc1  barwidth(0.31) color(none) lcolor("147 112 219") ///
	           ciopts(lcolor("purple%40")  recast(rcap) lwidth(vthin))
	local lc2  barwidth(0.27)  color(white) lcolor("0 153 153") ///
	           ciopts(lcolor("emerald%40") recast(rcap) lwidth(vthin))
	
* Code for graph 
  # d ;
  coefplot  (mnf_var_q1, rename(`var1'_q1="10%-30%") recast(bar) `lc1') 
			(mnm_var_q1, rename(`var2'_q1="10%-30%") recast(bar) `lc2')
			
            (mnf_var_q2, rename(`var1'_q2="30%-50%") recast(bar) `lc1') 
			(mnm_var_q2, rename(`var2'_q2="30%-50%") recast(bar) `lc2')
			
            (mnf_var_q3, rename(`var1'_q3="50%-70%") recast(bar) `lc1') 
			(mnm_var_q3, rename(`var2'_q3="50%-70%") recast(bar) `lc2')			
			
			(mnf_var_q4, rename(`var1'_q4="70%-90%") recast(bar) `lc1') 
			(mnm_var_q4, rename(`var2'_q4="70%-90%") recast(bar) `lc2'),
			 ciopts(recast(rcap) lcolor(gs7))  citop 
			 vertical nooffsets    format(%9.2f) 
			 addplot(scatter @b @at, ms(i) mlabel(@b) mlabpos(11) mlabcolor(black) mlabsize(vsmall))
			 plotregion(margin(b=0))
			 legend(order( 1 "Mean Female" 3 "Mean Male") row(1) pos(6)
			        size(vsmall)  symxsize(2) region(lstyle(none))) 
	         subtitle($subtitle, size(small) color("0 51 102") 
				        justification(left) pos(11))
			 ytitle(`ytitle', size(vsmall)) ylabel(70(10)100,labsize (vsmall))  
			 xtitle(`xtitle', size(vsmall)) xlabel (,labsize (vsmall)) xlabel(, angle(360))
			 graphregion(color(none))
			note("Rho:`corrf' is the overall correlation between female personal beliefs and FLP"
                 "Rho:`corrm'is the overall correlation between male personal beliefs and FLP"
				  , size (vsmall));
		# d cr; 	 
	
  * Saving Graph 
	graph save "$outputs_raw/Figures/Appendix/$out_name.gph", replace	
}
	
* Graph combination 
* ---------------------------------------------------------------------------
  gl title "Broad Norm: Men and women should have equal opportunities"	
  //gl subtitle "Correlation with macroeconomic indicators"
  gl output_name MacroNorm1
 # d;	 
  gr combine "$outputs_raw/Figures/Appendix/GDPNorm1.gph"
			 "$outputs_raw/Figures/Appendix/LFPNorm1.gph", 
				   graphregion(color(white)) 
				   title($title, size(small) color(dknavy) span pos(11))
	               graphregion(color(white))
				   ycommon
				   note("Source: Facebook Gender At Home (2020) and World Bank Indicators (2019)", 
				   size(tiny))
				   row(1);
 # d cr;

 * Saving and exporting graph
  graph save   "$outputs_raw/Figures/Appendix/$output_name.gph", replace		
  graph export "$outputs_raw/Figures/Appendix/$output_name.png", as(png) width(1000) replace 	 	
}

** =============================================================================
** Norm 2: Expenses are man responsibility even if wife can help
** =============================================================================	
if 1{	
* Individual Norm Female male with GDP 
* ------------------------------------------------------------------------------
if 1{
  gl outcome1a d_expens_agree_fem 
  gl outcome1b d_expens_agree_mal
  gl outcome2  ln_gdp_usd
  local vary   gdp4
  
** Mean of variable by gender  
 foreach quarter in 1 2 3 4{
  * Female
  local var $outcome1a
  gen       `var'_q`quarter'=`var' if `vary'==`quarter'
  mean      `var'_q`quarter' 
  estimates store mnf_var_q`quarter'
  drop `var'_q`quarter'
   
  * Male 
  local var $outcome1b
  gen       `var'_q`quarter'=`var' if `vary'==`quarter'
  mean      `var'_q`quarter' 
  estimates store mnm_var_q`quarter'
  drop `var'_q`quarter'
 }
  
 * Correlation by gender  
  corr      $outcome1a  $outcome2 
  local     corrf=round(r(rho),.01)
 
  corr      $outcome1b $outcome2
  local     corrm=round(r(rho),.01)

  
** Setting up graph code: 
    gl out_name "GDPNorm2"
	gl subtitle "Personal Beliefs and GDP" 
	
	local ytitle "Personal Beliefs (%)"
	local xtitle "GDP by quarter"
	
    local var1 $outcome1a
	local var2 $outcome1b
    local lc1  barwidth(0.31) color(white) lcolor("147 112 219") ///
	           ciopts(lcolor("purple%40")  recast(rcap) lwidth(vthin))
	local lc2  barwidth(0.27)  color(none) lcolor("0 153 153") ///
	           ciopts(lcolor("emerald%40") recast(rcap) lwidth(vthin))
	
* Code for graph 
  # d ;
  coefplot  (mnf_var_q1, rename(`var1'_q1="Q1") recast(bar) `lc1') 
			(mnm_var_q1, rename(`var2'_q1="Q1") recast(bar) `lc2')
			
            (mnf_var_q2, rename(`var1'_q2="Q2") recast(bar) `lc1') 
			(mnm_var_q2, rename(`var2'_q2="Q2") recast(bar) `lc2')
			
            (mnf_var_q3, rename(`var1'_q3="Q3") recast(bar) `lc1') 
			(mnm_var_q3, rename(`var2'_q3="Q3") recast(bar) `lc2')			
			
			(mnf_var_q4, rename(`var1'_q4="Q4") recast(bar) `lc1') 
			(mnm_var_q4, rename(`var2'_q4="Q4") recast(bar) `lc2'),
			 ciopts(recast(rcap) lcolor(gs7))  citop 
			 vertical nooffsets    format(%9.2f) 
			 addplot(scatter @b @at, ms(i) mlabel(@b) mlabpos(11) mlabcolor(black) mlabsize(vsmall))
			 plotregion(margin(b=0))
			 legend(order( 1 "Mean Female" 3 "Mean Male") row(1) pos(6)
			        size(vsmall)  symxsize(2) region(lstyle(none))) 
	         subtitle($subtitle, size(small) color("0 51 102") 
				        justification(left) pos(11))
			 ytitle(`ytitle', size(vsmall)) ylabel(0(10)90,labsize (vsmall)) 
			 xtitle(`xtitle', size(vsmall)) xlabel (,labsize (vsmall)) xlabel(, angle(360)) 
			 graphregion(color(none))
			 note("Rho:`corrf' is the overall correlation between female personal beliefs and GDP per capita"
                  "Rho:`corrm' is the overall correlation between male personal beliefs and GDP per capita".
				  , size (vsmall));
		# d cr; 	 
	
  * Saving Graph 
	graph save "$outputs_raw/Figures/Appendix/$out_name.gph", replace	
	
}	

* Individual Norm Female male with FLP
* ------------------------------------------------------------------------------	
if 1{
  gl outcome1a d_expens_agree_fem
  gl outcome1b d_expens_agree_mal
  gl outcome2  sl_tlf_cact_fe_zs
  local vary      LFP4
  
** Mean of variable by gender  
 foreach quarter in 1 2 3 4{
  * Female
  local var $outcome1a
  gen       `var'_q`quarter'=`var' if `vary'==`quarter'
  mean      `var'_q`quarter' 
  estimates store mnf_var_q`quarter'
  drop `var'_q`quarter'
   
  local var $outcome1b
  gen       `var'_q`quarter'=`var' if `vary'==`quarter'
  mean      `var'_q`quarter' 
  estimates store mnm_var_q`quarter'
  drop `var'_q`quarter'
 }
  

 * Correlation by gender  
  corr      $outcome1a  $outcome2 
  local     corrf=round(r(rho),.01)
 
  corr      $outcome1b $outcome2
  local     corrm=round(r(rho),.01)
  
** Setting up graph code: 
    gl out_name "LFPNorm2"
	gl subtitle "Personal Beliefs and Female Labor Force Participation" 
	
	local ytitle "Personal Beliefs(%)"
	local xtitle "FLFP (%)"
    local var1 $outcome1a
	local var2 $outcome1b
    local lc1  barwidth(0.31) color(white) lcolor("147 112 219") ///
	           ciopts(lcolor("purple%40")  recast(rcap) lwidth(vthin))
	local lc2  barwidth(0.27)  color(none) lcolor("0 153 153") ///
	           ciopts(lcolor("emerald%40") recast(rcap) lwidth(vthin))
	
* Code for graph 
  # d ;
  coefplot  (mnf_var_q1, rename(`var1'_q1="10%-30%") recast(bar) `lc1') 
			(mnm_var_q1, rename(`var2'_q1="10%-30%") recast(bar) `lc2')
			
            (mnf_var_q2, rename(`var1'_q2="30%-50%") recast(bar) `lc1') 
			(mnm_var_q2, rename(`var2'_q2="30%-50%") recast(bar) `lc2')
			
            (mnf_var_q3, rename(`var1'_q3="50%-70%") recast(bar) `lc1') 
			(mnm_var_q3, rename(`var2'_q3="50%-70%") recast(bar) `lc2')			
			
			(mnf_var_q4, rename(`var1'_q4="70%-90%") recast(bar) `lc1') 
			(mnm_var_q4, rename(`var2'_q4="70%-90%") recast(bar) `lc2'),
			 ciopts(recast(rcap) lcolor(gs7))  citop 
			 vertical nooffsets    format(%9.2f) 
			 addplot(scatter @b @at, ms(i) mlabel(@b) mlabpos(11) mlabcolor(black) mlabsize(vsmall))
			 plotregion(margin(b=0))
			 legend(order( 1 "Mean Female" 3 "Mean Male") row(1) pos(6)
			        size(vsmall)  symxsize(2) region(lstyle(none))) 
	         subtitle($subtitle, size(small) color("0 51 102") 
				        justification(left) pos(11))
			 ytitle(`ytitle', size(vsmall)) ylabel(0(10)90,labsize (vsmall))  
			 xtitle(`xtitle', size(vsmall)) xlabel (,labsize (vsmall)) xlabel(, angle(360))
			 graphregion(color(none))
			note("Rho:`corrf' is the overall correlation between female personal beliefs and FLP"
                 "Rho:`corrm'is the overall correlation between male personal beliefs and FLP"
				  , size (vsmall));
		# d cr; 	 
	
  * Saving Graph 
	graph save "$outputs_raw/Figures/Appendix/$out_name.gph", replace	
}
	
* Graph combination 
* ---------------------------------------------------------------------------
  gl title "Breadwinner Norm: Expenses are a man's responsibility even if his wife can help him"
  gl output_name MacroNorm2
 # d;	 
  gr combine "$outputs_raw/Figures/Appendix/GDPNorm2.gph"
			 "$outputs_raw/Figures/Appendix/LFPNorm2.gph", 
				   graphregion(color(white)) 
				   title($title, size(small) color(dknavy) span pos(11))
	               graphregion(color(white))
				   ycommon
				   note("Source: Facebook Gender At Home (2020) and World Bank Indicators (2019)", 
				   size(tiny))
				   row(1);
 # d cr;

 * Saving and exporting graph
  graph save  "$outputs_raw/Figures/Appendix/$output_name.gph", replace		
  graph export "$outputs_raw/Figures/Appendix/$output_name.png", as(png) width(1000) replace 	 	
}

** =============================================================================
** Norm 3: Woman's most important role is care of home and child
** ============================================================================= 
if 1{	
* Individual Norm Female male with GDP 
* ------------------------------------------------------------------------------
if 1{
  gl outcome1a d_woman_role_agree_fem
  gl outcome1b d_woman_role_agree_mal
  gl outcome2  ln_gdp_usd
  local vary   gdp4
  
** Mean of variable by gender  
 foreach quarter in 1 2 3 4{
  * Female
  local var $outcome1a
  gen       `var'_q`quarter'=`var' if `vary'==`quarter'
  mean      `var'_q`quarter' 
  estimates store mnf_var_q`quarter'
  drop `var'_q`quarter'
   
  * Male 
  local var $outcome1b
  gen       `var'_q`quarter'=`var' if `vary'==`quarter'
  mean      `var'_q`quarter' 
  estimates store mnm_var_q`quarter'
  drop `var'_q`quarter'
 }
  
 * Correlation by gender  
  corr      $outcome1a  $outcome2 
  local     corrf=round(r(rho),.01)
 
  corr      $outcome1b $outcome2
  local     corrm=round(r(rho),.01)

  
** Setting up graph code: 
    gl out_name "GDPNorm3"
	gl subtitle "Personal Beliefs and GDP" 
	
	local ytitle "Personal Beliefs (%)"
	local xtitle "GDP by quarter"
	
    local var1 $outcome1a
	local var2 $outcome1b
    local lc1  barwidth(0.31) color(white) lcolor("147 112 219") ///
	           ciopts(lcolor("purple%40")  recast(rcap) lwidth(vthin))
	local lc2  barwidth(0.27)  color(none) lcolor("0 153 153") ///
	           ciopts(lcolor("emerald%40") recast(rcap) lwidth(vthin))
	
* Code for graph 
  # d ;
  coefplot  (mnf_var_q1, rename(`var1'_q1="Q1") recast(bar) `lc1') 
			(mnm_var_q1, rename(`var2'_q1="Q1") recast(bar) `lc2')
			
            (mnf_var_q2, rename(`var1'_q2="Q2") recast(bar) `lc1') 
			(mnm_var_q2, rename(`var2'_q2="Q2") recast(bar) `lc2')
			
            (mnf_var_q3, rename(`var1'_q3="Q3") recast(bar) `lc1') 
			(mnm_var_q3, rename(`var2'_q3="Q3") recast(bar) `lc2')			
			
			(mnf_var_q4, rename(`var1'_q4="Q4") recast(bar) `lc1') 
			(mnm_var_q4, rename(`var2'_q4="Q4") recast(bar) `lc2'),
			 ciopts(recast(rcap) lcolor(gs7))  citop 
			 vertical nooffsets    format(%9.2f) 
			 addplot(scatter @b @at, ms(i) mlabel(@b) mlabpos(11) mlabcolor(black) mlabsize(vsmall))
			 plotregion(margin(b=0))
			 legend(order( 1 "Mean Female" 3 "Mean Male") row(1) pos(6)
			        size(vsmall)  symxsize(2) region(lstyle(none))) 
	         subtitle($subtitle, size(small) color("0 51 102") 
				        justification(left) pos(11))
			 ytitle(`ytitle', size(vsmall)) ylabel(0(10)90,labsize (vsmall)) 
			 xtitle(`xtitle', size(vsmall)) xlabel (,labsize (vsmall)) xlabel(, angle(360)) 
			 graphregion(color(none))
			 note("Rho:`corrf' is the overall correlation between female personal beliefs and GDP per capita"
                  "Rho:`corrm' is the overall correlation between male personal beliefs and GDP per capita".
				  , size (vsmall));
		# d cr; 	 
	
  * Saving Graph 
	graph save "$outputs_raw/Figures/Appendix/$out_name.gph", replace	
	
}	

* Individual Norm Female male with FLP
* ------------------------------------------------------------------------------	
if 1{
  gl outcome1a d_woman_role_agree_fem
  gl outcome1b d_woman_role_agree_mal
  gl outcome2  sl_tlf_cact_fe_zs
  local vary      LFP4
  
** Mean of variable by gender  
 foreach quarter in 1 2 3 4{
  * Female
  local var $outcome1a
  gen       `var'_q`quarter'=`var' if `vary'==`quarter'
  mean      `var'_q`quarter' 
  estimates store mnf_var_q`quarter'
  drop `var'_q`quarter'
   
  local var $outcome1b
  gen       `var'_q`quarter'=`var' if `vary'==`quarter'
  mean      `var'_q`quarter' 
  estimates store mnm_var_q`quarter'
  drop `var'_q`quarter'
 }
  

 * Correlation by gender  
  corr      $outcome1a  $outcome2 
  local     corrf=round(r(rho),.01)
 
  corr      $outcome1b $outcome2
  local     corrm=round(r(rho),.01)
  
** Setting up graph code: 
    gl out_name "LFPNorm3"
	gl subtitle "Personal Beliefs and Female Labor Force Participation" 
	
	local ytitle "Personal Beliefs(%)"
	local xtitle "FLFP (%)"
    local var1 $outcome1a
	local var2 $outcome1b
    local lc1  barwidth(0.31) color(white) lcolor("147 112 219") ///
	           ciopts(lcolor("purple%40")  recast(rcap) lwidth(vthin))
	local lc2  barwidth(0.27)  color(none) lcolor("0 153 153") ///
	           ciopts(lcolor("emerald%40") recast(rcap) lwidth(vthin))
	
* Code for graph 
  # d ;
  coefplot  (mnf_var_q1, rename(`var1'_q1="10%-30%") recast(bar) `lc1') 
			(mnm_var_q1, rename(`var2'_q1="10%-30%") recast(bar) `lc2')
			
            (mnf_var_q2, rename(`var1'_q2="30%-50%") recast(bar) `lc1') 
			(mnm_var_q2, rename(`var2'_q2="30%-50%") recast(bar) `lc2')
			
            (mnf_var_q3, rename(`var1'_q3="50%-70%") recast(bar) `lc1') 
			(mnm_var_q3, rename(`var2'_q3="50%-70%") recast(bar) `lc2')			
			
			(mnf_var_q4, rename(`var1'_q4="70%-90%") recast(bar) `lc1') 
			(mnm_var_q4, rename(`var2'_q4="70%-90%") recast(bar) `lc2'),
			 ciopts(recast(rcap) lcolor(gs7))  citop 
			 vertical nooffsets    format(%9.2f) 
			 addplot(scatter @b @at, ms(i) mlabel(@b) mlabpos(11) mlabcolor(black) mlabsize(vsmall))
			 plotregion(margin(b=0))
			 legend(order( 1 "Mean Female" 3 "Mean Male") row(1) pos(6)
			        size(vsmall)  symxsize(2) region(lstyle(none))) 
	         subtitle($subtitle, size(small) color("0 51 102") 
				        justification(left) pos(11))
			 ytitle(`ytitle', size(vsmall)) ylabel(0(10)90,labsize (vsmall))  
			 xtitle(`xtitle', size(vsmall)) xlabel (,labsize (vsmall)) xlabel(, angle(360))
			 graphregion(color(none))
			note("Rho:`corrf' is the overall correlation between female personal beliefs and FLP"
                 "Rho:`corrm'is the overall correlation between male personal beliefs and FLP"
				  , size (vsmall));
		# d cr; 	 
	
  * Saving Graph 
	graph save "$outputs_raw/Figures/Appendix/$out_name.gph", replace	
}
	
* Graph combination 
* ---------------------------------------------------------------------------
  gl title "Caregiver Norm: Women's most important role is to take care of her home and children"
  gl output_name MacroNorm3
 # d;	 
  gr combine "$outputs_raw/Figures/Appendix/GDPNorm3.gph"
			 "$outputs_raw/Figures/Appendix/LFPNorm3.gph", 
				   graphregion(color(white)) 
				   title($title, size(small) color(dknavy) span pos(11))
	               graphregion(color(white))
				   ycommon
				   note("Source: Facebook Gender At Home (2020) and World Bank Indicators (2019)", 
				   size(tiny))
				   row(1);
 # d cr;

 * Saving and exporting graph
  graph save   "$outputs_raw/Figures/Appendix/$output_name.gph", replace		
  graph export "$outputs_raw/Figures/Appendix/$output_name.png", as(png) width(1000) replace 	 	
}


******************************************************************************** 
/// END OF DOFILE

  