*** ======================================================================== ***
*   Table D2: Correlates of Norm Misperceptions
*** ======================================================================== ***
/* Description: This dofile should be run to replicate th kernel density graphs 
                by norm and region of the world. */
				
gl  table_D2    1				
				
*** ======================================================================== ***
*   Tables D2
*** ======================================================================== ***				
if $table_D2{
** Load Dataset 
   use "$data/Final/GenderAtHome_DataAnalysisInd.dta", clear
   
** Restrincting to our sampleo of analysis which comprises: 
   keep if d_indchar_sample==1

** Defining variables for output_name
   la var  female_respondent "Female (0/1)"
  
** Defining globals
 * Outcomes and controls 
   # d;
   gl outcomes1      d_und_aeq_opport      d_over_aeq_opport 
					 d_und_aexpens         d_over_aexpens
					 d_und_awoman_role     d_over_awoman_role;
					 
   gl individ        female_respondent
                     hhd_has_spo 
					 d_age_2  
				     d_hhd_own_edu_2
					 d_hhd_urb_2
					 hhd_has_spo_fem 
					 d_age_2_fem   
				     d_hhd_own_edu_2_fem 
					 d_hhd_urb_2_fem;
   gl demographics   $individ;
   gl region_fe      i.region;
   gl country_fe     i.country_num;					 				 
   # d cr; 
 
 * Set of specifications
   gl xlist1   $demographics  $country_fe

** -----------------------------------------------------------------------------   
*  Labor Outcomes - Correlation with Gender Equality in Opportunities
** -----------------------------------------------------------------------------
	
** Title and output_name: 
   gl H "Table D2: Correlates of Norm Miscperceptions"
   gl output_name "Misp_IndividualChar"
 	
** Regression Code
** -----------------------------------------------------------------------------
	gl controls ${xlist1}
	foreach var in $outcomes1{
	** Reg Code
	eststo: reg  `var'  ${controls}, robust	 


	* Saving stats 
	sum    `var' if e(sample) & female_respondent==1 
	estadd scalar mean_var_fem=r(mean) 

	sum    `var' if e(sample) & female_respondent==0 
	estadd scalar mean_var_mal=r(mean) 	 
	
	estadd local  SAMPLE      "ALL"
	estadd local  COUNTRY_FE "YES"

	   
	}	   

 * Output
   # d;
   esttab using  "$outputs_raw/Tables/Appendix/$output_name.csv", title("${H}") 
			   stats( N                 r2 
			          mean_var_fem 
					  mean_var_mal  
			          SAMPLE COUNTRY_FE, fmt(0 2 2 2 2 2 2 2 2 2 2 2 2 2)       
			   labels( "Observations" 
			           "Adjusted R-squared"        				
					   "Mean Female" 
					   "Mean Male"
					   "Sample" 
					   "Country FE"))  
			   drop (*country_num*)
			   label  brackets plain  numbers depvars
			   star(* 0.1 ** 0.05 *** 0.01)   b(%9.2f) se(%9.2f) replace;
   # d cr;		
	    
* Drop store values	 
  eststo clear		 

** Exporting to unique file 
** ------------------------------------------	
    local svdate: di %tdCCYYNNDD daily("$S_DATE", "DMY")
    disp "`svdate'" 			   
	preserve 
	* Import table from csv
	import delimited "$outputs_raw/Tables/Appendix/$output_name.csv", ///
	clear delimiter(comma)

	* Exporting into common file 
	export excel using "$outputs_raw/Tables\GenderAtHome_AppendixTables_`svdate'.xlsx", ///
				 sheet("$output_name", modify) 
	restore   
 
}

				