*** ======================================================================== ***
*   Figure 1: Gender Gaps in Personal Beliefs and Perceived 
*   Community Norms by Region
*** ======================================================================== ***
/* Description: This dofiles replicates figures included in figure 1.*/

* Loading Dataset at the Country Level 
  use "$data/Final/GenderAtHome_DataAnalysisCountry.dta", clear 

* Set scheme and font for all graphs 
  set scheme white_tableau
  graph set window fontface "Times New Roman"  
  
* Collpase at the country level 
  # d;
  gl set_norms   d_eq_opport_agree_fem  eq_opport_neighb_fem 
				 d_eq_opport_agree_mal  eq_opport_neighb_mal
				 d_expens_agree_fem      expens_neigh_fem 
				 d_expens_agree_mal      expens_neigh_mal
				 d_woman_role_agree_fem  woman_role_neigh_fem
				 d_woman_role_agree_mal  woman_role_neigh_mal;
  # d cr;				 	   
  collapse $set_norms, by (region)
  la def region 1 "East Asia & Pacific" 2 "Europe & Central Asia"    ///
                3 "Latin America & Caribbean" 4 "Middle East & North Africa "    ///
                5 "North America" 6 "South Asia"    ///
				7 "Sub-Saharan Africa", modify
				
  la val region region 				

** -----------------------------------------------------------------------------   
** Norm 1: Men and women shoudl have equal opportunities 
** -----------------------------------------------------------------------------   
if 1{
  gl title "Broad Norm: Men and women should have equal opportunities"
  gl subtitle "{it:Gender Gaps in Personal Beliefs and Perceived Community Norms}"
  gl output_name RegionGenderNorm1
 		
* Selecting variables to plot
  local var1  d_eq_opport_agree_fem
  local var2  d_eq_opport_agree_mal 
  local var3  eq_opport_neighb_fem
  local var4  eq_opport_neighb_mal  
  
* Graph Options 
  local varx  region
  local m1 msiz(5pt) mlw(0pt) mc("147 112 219") 
  local m2 msiz(5pt) mlw(0pt) mc("0 153 153")
  local m3 msiz(5pt) mlw(0pt) mc("218 165 32") 
  local m4 msiz(5pt) mlw(0pt) mc("199 21 133")
  local l1 lw(0.5pt) lc("119 136 153")   
  local l2 lw(0.5pt) lc("218 165 32")  
  
  
 * Twoway graph 
  # d;
	tw pcspike  `var1' `varx' `var2' `varx', `l1' ||
	   pcspike  `var3' `varx' `var4' `varx', `l2'
				|| scatter `var1' `varx', `m1'                                           
				|| scatter `var2' `varx', `m2'  
				|| scatter `var3' `varx', `m3'                                           
				|| scatter `var4' `varx', `m4' 				
				||  , legend(order( 3 "Female - Personal Beliefs"
									6 "Female - Perceived Community Norms"
									4 "Male - Personal Beliefs" 
									5 "Male - Perceived Community Norms") 
					  color("`r(p2)'") row (2)
					  pos(6) size(vsmall)) xlab(,grid)                     
					  title($title, size(small)  color(navy) span pos(11)) 
					  subtitle($subtitle, size(vsmall)  color(dknavy) span pos(11))  
					  ytitle("%", size(vsmall))
					  xtitle("Region of the world", size (vsmall))
					  ylab(50(5)100, grid labsize (vsmall))
					  xlabel(1 "EAP" 2 "ECA" 3 "LAC" 4 "MENA"    
							 5 "North America" 6 "South Asia" 
							 7 "SSA", labsize (vsmall))   
					  bgcolor (white) graphregion(color(white))
					  note("Personal beliefs are an aggregate of the percentage of the sample who agree with the statement."
					       "Perceived community norms are an aggregate of the proportion of neighbors who they believe agree with the statement."
						   "Aggregates are taken at the country level and then averaged by region of the world.", size(vsmall));
	# d cr;	  

* Saving and exporting graph
  graph save   "$outputs_raw/Figures/Main/${output_name}.gph", replace		
  graph export "$outputs_raw/Figures/Main/${output_name}.png", as(png) width(1000) replace 	
}

** -----------------------------------------------------------------------------   
** Norm 2: Expenses are man responsibility even if wife can help
** -----------------------------------------------------------------------------   
if 1{  		
  gl title "Breadwinner Norm: Expenses are a man's responsibility even if his wife can help him"
  gl subtitle "{it:Gender Gaps in Personal Beliefs and Perceived Community Norms}"
  gl output_name RegionGenderNorm2
  
* Selecting variables to plot
  local var1  d_expens_agree_fem
  local var2  d_expens_agree_mal 
  local var3  expens_neigh_fem
  local var4  expens_neigh_mal  
  
* Graph Options 
  local varx  region
  local m1 msiz(5pt) mlw(0pt) mc("147 112 219") 
  local m2 msiz(5pt) mlw(0pt) mc("0 153 153")
  local m3 msiz(5pt) mlw(0pt) mc("218 165 32") 
  local m4 msiz(5pt) mlw(0pt) mc("199 21 133")
  local l1 lw(0.5pt) lc("119 136 153")   
  local l2 lw(0.5pt) lc("218 165 32")  
  
  
 * Twoway graph 
  # d;
	tw pcspike  `var1' `varx' `var2' `varx', `l1' ||
	   pcspike  `var3' `varx' `var4' `varx', `l2'
				|| scatter `var1' `varx', `m1'                                           
				|| scatter `var2' `varx', `m2'  
				|| scatter `var3' `varx', `m3'                                           
				|| scatter `var4' `varx', `m4' 				
				||  , legend(order( 3 "Female - Personal Beliefs"
									6 "Female - Perceived Community Norms"
									4 "Male - Personal Beliefs" 
									5 "Male - Perceived Community Norms") 
					  color("`r(p2)'") row (2)
					  pos(6) size(vsmall)) xlab(,grid)                     
					  title($title, size(small)  color(navy) span pos(11)) 
					  subtitle($subtitle, size(vsmall)  color(dknavy) span pos(11))  
					  ytitle("%", size(vsmall))
					  xtitle("Region of the world", size (vsmall))
					  ylab(0(5)80, grid labsize (vsmall))
					  xlabel(1 "EAP" 2 "ECA" 3 "LAC" 4 "MENA"    
							 5 "North America" 6 "South Asia" 
							 7 "SSA", labsize (vsmall))   
					  bgcolor (white) graphregion(color(white))
					  note("Personal beliefs are an aggregate of the percentage of the sample who agree with the statement."
					       "Perceived community norms are an aggregate of the proportion of neighbors who they believe agree with the statement."
						   "Aggregates are taken at the country level and then averaged by region of the world.", size(vsmall));
	# d cr;	  

* Saving and exporting graph
  graph save   "$outputs_raw\Figures/Main/${output_name}.gph", replace		
  graph export "$outputs_raw\Figures/Main/${output_name}.png", as(png) width(1000) replace 	
}


** -----------------------------------------------------------------------------   
** Norm 3: Woman's most important role is care of home and child
** -----------------------------------------------------------------------------   
if 1{  		
  gl title    "Caregiver Norm: Women's most important role is to take care of her home and children"
  gl subtitle "{it:Gender Gaps in Personal Beliefs and Perceived Community Norms}"
  gl output_name RegionGenderNorm3
  
* Selecting variables to plot
  local var1  d_woman_role_agree_fem
  local var2  d_woman_role_agree_mal 
  local var3  woman_role_neigh_fem
  local var4  woman_role_neigh_mal  
  
* Graph Options 
  local varx  region
  local m1 msiz(5pt) mlw(0pt) mc("147 112 219") 
  local m2 msiz(5pt) mlw(0pt) mc("0 153 153")
  local m3 msiz(5pt) mlw(0pt) mc("218 165 32") 
  local m4 msiz(5pt) mlw(0pt) mc("199 21 133")
  local l1 lw(0.5pt) lc("119 136 153")   
  local l2 lw(0.5pt) lc("218 165 32")  
  
  
 * Twoway graph 
  # d;
	tw pcspike  `var1' `varx' `var2' `varx', `l1' ||
	   pcspike  `var3' `varx' `var4' `varx', `l2'
				|| scatter `var1' `varx', `m1'                                           
				|| scatter `var2' `varx', `m2'  
				|| scatter `var3' `varx', `m3'                                           
				|| scatter `var4' `varx', `m4' 				
				||  , legend(order( 3 "Female - Personal Beliefs"
									6 "Female - Perceived Community Norms"
									4 "Male - Personal Beliefs" 
									5 "Male - Perceived Community Norms") 
					  color("`r(p2)'") row (2)
					  pos(6) size(vsmall)) xlab(,grid)                     
					  title($title, size(small)  color(navy) span pos(11)) 
					  subtitle($subtitle, size(vsmall)  color(dknavy) span pos(11))  
					  ytitle("%", size(vsmall))
					  xtitle("Region of the world", size (vsmall))
					  ylab(0(5)80, grid labsize (vsmall))
					  xlabel(1 "EAP" 2 "ECA" 3 "LAC" 4 "MENA"    
							 5 "North America" 6 "South Asia" 
							 7 "SSA", labsize (vsmall))   
					  bgcolor (white) graphregion(color(white))
					  note("Personal beliefs are an aggregate of the percentage of the sample who agree with the statement."
					       "Perceived community norms are an aggregate of the proportion of neighbors who they believe agree with the statement."
						   "Aggregates are taken at the country level and then averaged by region of the world.", size(vsmall));
	# d cr;	  

* Saving and exporting graph
  graph save   "$outputs_raw\Figures/Main/${output_name}.gph", replace		
  graph export "$outputs_raw\Figures/Main/${output_name}.png", as(png) width(1000) replace 	
}

******************************************************************************** 
/// END OF DOFILE
