*** ======================================================================== ***
*   Maps 2-4: Gender Norms at the Country level
*** ======================================================================== ***
/* Description: This dofiles replicates maps included in the main paper. However, 
                it should be noted that the maps included in the paper were 
				modified by WBG Cartography Unit to follow the WB guidelines.*/
				
* Activate each graph 	
  gl map_1    1
  gl map_2    1
  gl map_3    1
  
** Load Mapa Dataset
   use  "$data/Final/GenderAtHome_DataAnalysisMaps.dta", clear
  
*** ----------------------------------------------------------------------------				
*   BROADER NORM
*** ----------------------------------------------------------------------------	

if $map_1{	


* Generate the colors
  colorpalette viridis, n(12) nograph reverse
  local colors `r(p)'
  
* Options of the map layout   
  # d;
  gl map_opt id(id) 
			 clmethod(custom)  
			 fcolor("`colors'")    clbreaks(0(5)55) 
			 legstyle(2) legend(pos(7) size(2.8) region(fcolor(gs15)))   
			 ocolor(white ..) osize(0.05 ..) 
			 legend(position(8) 
			 	label(1 "No data")    
				label(2 "0 to 5") 
				label(3 "5 to 10") 
				label(4 "10 to 15") 
				label(5 "15 to 20") 
				label(6 "20 to 25") 
				label(7 "25 to 30") 
				label(8 "35 to 40") 
				label(9 "45 to 50") 
				label(10 "50 to 55"))
				legend (size(small));
  # d cr;			 
				 
	
* Specific code for norm   
	gl title "Broad Norm: Men and women should have equal opportunities"
    gl subtitle "{it:Misperception of the norm: |Perceived Community Norm - Personal Beliefs (%)|}"	
	gl output_name    Map_norm1 
	
	
	# d;
	spmap pign_eq_opport_country using "$data/Intermediate\OtherDatasets/world_shape_coord"
	if ADMIN!="Antarctica", $map_opt 
    subtitle("${subtitle}", size(*0.8)) 
	title("${title}", size(*0.8)) 
	note("Misperception is determined by the disparity between the Community Perceived Norm (on a 0-100 scale) and the Aggregate Level of Agreement with the norm within the country (on a 0-100 scale)."
	"Here we present the absolute values of the misperception as all countries have a negative value suggesting a general misperception of the support for gender equality globally."
	"Darker shades of the map represent a greater misperception of the norm i.e. a greater underestimation in the level of support for gender equality in opportunities in the country.  "
	"Source:Gender At Home Data 2020.", size(2))
	saving("$outputs_raw/Figures/Main/${output_name}", replace);
	# d cr;
	
  * Exporting graph 
	graph export "$outputs_raw/Figures/Main/${output_name}.png", as(png) width(1000) replace 
		
}
	
*** ----------------------------------------------------------------------------				
*   BREADWINNER NORM 
*** ----------------------------------------------------------------------------				
if $map_2{		
	
* Generate the colors
  colorpalette viridis, n(12) nograph reverse
  local colors `r(p)'	
	
* Options of the map layout   
  # d;
  gl map_opt id(id) 
			 clmethod(custom)  
			 fcolor("`colors'")    clbreaks(-15(5)40) 
			 legstyle(2) legend(pos(7) size(2.8) region(fcolor(gs15)))   
			 ocolor(white ..) osize(0.05 ..)
			  legend(position(8) 
			 	label(1 "No data")    
				label(2 "-15 to -10") 
				label(3 "-10 to -5") 
				label(4 "-5 to 0") 
				label(5 "0 to 5") 
				label(6 "5 to 10") 
				label(7 "10 to 15") 
				label(8 "15 to 20") 
				label(9 "20 to 25") 
				label(10 "25 to 30")
				label(11 "30 to 35") 
				label(12 "35 to 40"))
				legend (size(small));
  # d cr;			 
				 
	
* Specific code for norm   
    gl title "Breadwinner Norm: Expenses are a man's responsibility even if his wife can help him"
    gl subtitle "{it:Misperception from the norm: Perceived Community Norm - Personal Beliefs (%)}"	
	gl output_name    Map_norm2 
	
	# d;
	spmap pign_expens_country using "$data/Intermediate\OtherDatasets/world_shape_coord"
	if ADMIN!="Antarctica", $map_opt 
    subtitle("${subtitle}", size(*0.8)) 
	title("${title}", size(*0.8)) 
	note("Misperception is determined by the disparity between the Community Perceived Norm (on a 0-100 scale) and the Aggregate Level of Agreement with the norm within the country (on a 0-100 scale)."
	 "Here we present the actual values of the misperception – some countries have a positive value (overestimation) and some a negative value (underestimation) suggesting varying degrees of misperception."
	 "Darker shades of the map suggest an overestimation of the male breadwinner norm – individuals think their community is more gender conservative or stereotypical than actual beliefs in that country."
	 "Lighter shades of the map suggest an underestimation of the male breadwinner norm – individuals think their community is more gender progressive or counter-stereotypical than actual beliefs in that country."
	"Source:Gender At Home Data 2020.", size(2))
	saving("$outputs_raw/Figures/Main/${output_name}", replace);
	# d cr;
	
  * Exporting graph 
	graph export "$outputs_raw/Figures/Main/${output_name}.png", as(png) width(1000) replace 
		
}
		
*** ----------------------------------------------------------------------------				
*   CARETAKER
*** ----------------------------------------------------------------------------				
if $map_3{		
	
* Generate the colors
  colorpalette viridis, n(12) nograph reverse
  local colors `r(p)'	
	
* Options of the map layout   
  # d;
  gl map_opt id(id) 
			 clmethod(custom)  
			 fcolor("`colors'")     clbreaks(-20 -10 -5 0 10 15 20 25 30 35 40 50) 
			 legstyle(2) legend(pos(7) size(2.8) region(fcolor(gs15)))   
			 ocolor(white ..) osize(0.05 ..)
			 legend(position(8) 
			 	label(1 "No data")    
				label(2 "-20 to -10") 
				label(3 "-10 to -5") 
				label(4 "-5 to 0") 
				label(5 "0 to 10") 
				label(6 "10 to 15") 
				label(7 "15 to 20") 
				label(8 "20 to 25") 
				label(9 "25 to 30")
				label(10 "30 to 35") 
				label(11 "35 to 40") 
				label(12 "40 to 50"))
				legend (size(small));
  # d cr;			 
				 
	
* Specific code for norm   
  gl title    "Caregiver Norm: Women's most important role is to take care of her home and children"
    gl subtitle "{it:Misperception from the norm: Perceived Community Norm - Personal Beliefs (%)}"	
	gl output_name    Map_norm3 
	
	# d;
	spmap pign_woman_role_country using "$data/Intermediate\OtherDatasets/world_shape_coord"
	if ADMIN!="Antarctica", $map_opt 
    subtitle("${subtitle}", size(*0.8)) 
	title("${title}", size(*0.8)) 
	note("Misperception is determined by the disparity between the Community Perceived Norm (on a 0-100 scale) and the Aggregate Level of Agreement with the norm within the country (on a 0-100 scale)."
	 "Here we present the actual values of the misperception – some countries have a positive value (overestimation) and some a negative value (underestimation) suggesting varying degrees of misperception."
	 "Darker shades of the map suggest an overestimation of the female caregiver norm – individuals think their community is more gender conservative or stereotypical than actual beliefs in that country."
	 "Lighter shades of the map suggest an underestimation of the female caregiver norm – individuals think their community is more gender progressive or counter-stereotypical than actual beliefs in that country.  "
	"Source:Gender At Home Data 2020.", size(2))
	saving("$outputs_raw/Figures/Main/${output_name}", replace);
	# d cr;
	
  * Exporting graph 
	graph export "$outputs_raw/Figures/Main/${output_name}.png", as(png) width(1000) replace 
		
}
	
	
********************************************************************************
// END OF DOFILE 
        
  