*** ======================================================================== ***
*   Figure 2-4: Gender Norms at the Country level
*** ======================================================================== ***
/* Description: This dofiles replicates figure 2, 3 and 4 where individual 
                and community norms are display at the  country level*/
				
* Activate each graph 	
  gl figure_2    1
  gl figure_3    1
  gl figure_4    1
  
** =============================================================================
** Preparing Data 
** =============================================================================	
if 1{	
** Load Dataset 
   use "$data/Final/GenderAtHome_DataAnalysisInd.dta", clear

 * Set scheme and font for all graphs 
  	set scheme white_tableau
	graph set window fontface "Times New Roman"	   
	
 * Keeping sample has all individual characteristics and with country code clear
   drop if code_iso3==""
   keep if d_indchar_sample==1
   bysort sub_region: gen consq=_n 
   bysort sub_region: egen num_ind=max(consq)

* Collpase at the country level 
  gl set_norms est_eq_opport_neighb est_expens_neigh est_woman_role_neigh    ///
					 d_eq_opport_agree d_expens_agree d_woman_role_agree
  collapse $set_norms region num_ind, by (sub_region)
  la val region regions 


* Transforming variables to 100% 
  foreach var of varlist  d_eq_opport_agree d_expens_agree d_woman_role_agree{
	replace `var'=`var'*100
  }


* Generate pluratistic ignorance so we can sort set of countries 
  gen pluigno1=est_eq_opport_neighb - d_eq_opport_agree
  gen pluigno2=est_expens_neigh - d_expens_agree
  gen pluigno3=est_woman_role_neigh - d_woman_role_agree
  
  sort pluigno1
  gen order_pluigno1=_n
  gen d_higher_pluigno1=(order_pluigno1>58)

  sort pluigno2
  gen order_pluigno2=_n
  gen d_higher_pluigno2=(order_pluigno2>58)  

  sort pluigno3
  gen order_pluigno3=_n
  gen d_higher_pluigno3=(order_pluigno3>58) 
  
  
  * Saving temporary dataset
  saveold "$data/Final/GenderAtHome_DataCountry.dta", replace
} 
				
*** ======================================================================== ***
*   Figure 2: Gender Equality in opportunities
*** ======================================================================== ***
if $figure_2{

	
* Norm 1 by region: PART 1 
* -----------------------------------------------------------------------------
program norm1_part1
if 1{
 * Load Country level Data
    use "$data/Final/GenderAtHome_DataCountry.dta", clear 
	
 * Setting main title 	
    gl title "Broad Norm: Men and women should have equal opportunities"
	gl subtitle "{it:Personal Beliefs and Perceived Community Norms}"
	gl output_name CountryNorm1_part1
	
	drop if d_higher_pluigno1==0
	* Prepare dataset to graph 
	gen norm1=est_eq_opport_neighb
	gen norm2=d_eq_opport_agree
	local tosort pluigno1
	capt drop i x0
	gen x0=0
	sort `tosort'
	drop if `tosort'==.
	gen i=_n
	gsort -i

	qui des
	forvalues j = 1/`r(N)' {
		 local o `o' "`=sub_region[`j']'"
	}
	local j = `r(N)'
	foreach o2 of local o {
	local ylab `ylab' `j--' "`o2'"
	}


	* Generate options 
	local m1 msiz(3.5pt) mlw(0pt) mc("147 112 219") 
	local m2 msiz(3.5pt) mlw(0pt) mc("0 153 153")
	local l lw(0.5pt) 

* Twoway graph 
	# d;
	tw pcspike  i norm1  i norm2, `l' lc("0 153 153")                       
				|| scatter i norm1, `m1'                                              
				|| scatter i norm2, `m2'                                              
				||  , legend(order( 2 "Community" 3 "Individual") color("`r(p2)'") 
					  pos(6) size(vsmall) row(1)) ///
					  ylabel(`ylab', labc("`tcol'") angle(0))                       
					  title($title, size(small)  color(dknavy) span pos(11))   
					  subtitle($subtitle, size(vsmall) span pos(11))
					  ytitle("") ylab(, nogrid labc("gs9") labsize (tiny))
					  xlabel(0(5)100,labsize (vsmall)) xlab(,grid)  
					  bgcolor (white) graphregion(color(white))
					  ;
	# d cr;				  
* Saving and exporting graph
	graph save  "$outputs_raw/Figures/Main/${output_name}.gph", replace		
	graph export "$outputs_raw/Figures/Main/${output_name}.png", ///
	             as(png) width(1000) replace 
	
* Drop store values	 
  eststo clear		
}
end
norm1_part1


** Norm 1 by region: PART 2 
** -----------------------------------------------------------------------------
program norm1_part2
if 1{	
 * Load Country level Data
    use "$data/Final/GenderAtHome_DataCountry.dta", clear 
	
 * Setting main title 	
    gl title "Broad Norm: Men and women should have equal opportunities"
	gl subtitle "{it:Personal Beliefs and Perceived Community Norms}"
	gl output_name CountryNorm1_part2
		
	drop if d_higher_pluigno1==1
	* Prepare dataset to graph 
	gen norm1=est_eq_opport_neighb
	gen norm2=d_eq_opport_agree
	local tosort pluigno1
	capt drop i x0
	gen x0=0
	sort `tosort'
	drop if `tosort'==.
	gen i=_n
	gsort -i

	local tcol ""
	local ylab ""	
	qui des
	forvalues j = 1/`r(N)' {
		 local o `o' "`=sub_region[`j']'"
	}
	local j = `r(N)'
	foreach o2 of local o {
	local ylab `ylab' `j--' "`o2'"
	}


	* Generate options 
	local m1 msiz(3.5pt) mlw(0pt) mc("147 112 219") 
	local m2 msiz(3.5pt) mlw(0pt) mc("0 153 153")
	local l lw(0.5pt) 

* Twoway graph 
	# d;
	tw pcspike  i norm1  i norm2, `l' lc("0 153 153")                       
				|| scatter i norm1, `m1'                                              
				|| scatter i norm2, `m2'                                              
				||  , legend(order( 2 "Community" 3 "Individual") color("`r(p2)'") 
					  pos(6) size(vsmall) row(1)) ///
					  ylabel(`ylab', labc("`tcol'") angle(0))                       
					  title($title, size(small)  color(dknavy) span pos(11))   
					  subtitle($subtitle, size(vsmall) span pos(11))
					  ytitle("") ylab(, nogrid labc("gs9") labsize (tiny))
					  xlabel(0(5)100,labsize (vsmall)) xlab(,grid)  
					  bgcolor (white) graphregion(color(white));
	# d cr;				  

* Saving and exporting graph
	graph save  "$outputs_raw/Figures/Main/${output_name}.gph", replace		
	graph export "$outputs_raw/Figures/Main/${output_name}.png", as(png) width(1000) replace 	  
}
end
norm1_part2

// Dropping temporary dofiles
program drop norm1_part1
program drop norm1_part2
}
	
*** ======================================================================== ***
*   Figure 3: Male Breadwinner Norm
*** ======================================================================== ***
if $figure_3{
* Load Country level Data
    use "$data/Final/GenderAtHome_DataCountry.dta", clear 
*  Norm 2 by region: PART 1 
** -----------------------------------------------------------------------------
program norm2_part1
if 1{
gl title    "Breadwinner Norm: Expenses are a man's responsibility even if his wife can help him"
gl output_name CountryNorm2_part1
drop if d_higher_pluigno2==0
* Prepare dataset to graph 
gen norm1=est_expens_neigh
gen norm2=d_expens_agree
local tosort pluigno2
capt drop i x0
gen x0=0
sort `tosort'
drop if `tosort'==.
gen i=_n
gsort -i

qui des
forvalues j = 1/`r(N)' {
     local o `o' "`=sub_region[`j']'"
}
local j = `r(N)'
foreach o2 of local o {
local ylab `ylab' `j--' "`o2'"
}


* Generate options 
local m1 msiz(3.5pt) mlw(0pt) mc("147 112 219") 
local m2 msiz(3.5pt) mlw(0pt) mc("0 153 153")
local l lw(0.5pt) 


* Twoway graph 
	# d;
	tw pcspike  i norm1  i norm2, `l' lc("0 153 153")                       
				|| scatter i norm1, `m1'                                              
				|| scatter i norm2, `m2'                                              
				||  , legend(order( 2 "Community" 3 "Individual") color("`r(p2)'") 
					  pos(6) size(vsmall) row(1)) ///
					  ylabel(`ylab', labc("`tcol'") angle(0))                       
					  title($title, size(small)  color(dknavy) span pos(11))   
					  subtitle($subtitle, size(vsmall) span pos(11))
					  ytitle("") ylab(, nogrid labc("gs9") labsize (tiny))
					  xlabel(0(5)100,labsize (vsmall)) xlab(,grid)  
					  bgcolor (white) graphregion(color(white));
	# d cr;				  

* Saving and exporting graph
graph save  "$outputs_raw/Figures/Main/${output_name}.gph", replace		
graph export "$outputs_raw/Figures/Main/${output_name}.png", as(png) width(1000) replace 	  				  
}
end 
norm2_part1


*  Norm 2 by region: PART 2 
** -----------------------------------------------------------------------------
program norm2_part2
if 1{
* Load Country level Data
    use "$data/Final/GenderAtHome_DataCountry.dta", clear 	

gl title    "Breadwinner Norm: Expenses are a man's responsibility even if his wife can help him"
gl output_name CountryNorm2_part2
 
drop if d_higher_pluigno2==1
* Prepare dataset to graph 
gen norm1=est_expens_neigh
gen norm2=d_expens_agree
local tosort pluigno2
capt drop i x0
gen x0=0
sort `tosort'
drop if `tosort'==.
gen i=_n
gsort -i

qui des
forvalues j = 1/`r(N)' {
     local o `o' "`=sub_region[`j']'"
}
local j = `r(N)'
foreach o2 of local o {
local ylab `ylab' `j--' "`o2'"
}

* Generate options 
local m1 msiz(3.5pt) mlw(0pt) mc("147 112 219") 
local m2 msiz(3.5pt) mlw(0pt) mc("0 153 153")
local l lw(0.5pt) 


* Twoway graph 
	# d;
	tw pcspike  i norm1  i norm2, `l' lc("0 153 153")                       
				|| scatter i norm1, `m1'                                              
				|| scatter i norm2, `m2'                                              
				||  , legend(order( 2 "Community" 3 "Individual") color("`r(p2)'") 
					  pos(6) size(vsmall) row(1)) ///
					  ylabel(`ylab', labc("`tcol'") angle(0))                       
					  title($title, size(small)  color(dknavy) span pos(11))   
					  subtitle($subtitle, size(vsmall) span pos(11))
					  ytitle("") ylab(, nogrid labc("gs9") labsize (tiny))
					  xlabel(0(5)100,labsize (vsmall)) xlab(,grid)  
					  bgcolor (white) graphregion(color(white));
	# d cr;			  
* Saving and exporting graph
graph save  "$outputs_raw/Figures/Main/${output_name}.gph", replace		
graph export "$outputs_raw/Figures/Main/${output_name}.png", as(png) width(1000) replace 
}

end 
norm2_part2

// Dropping temporary programs
program drop  norm2_part1
program drop  norm2_part2
}	
	
*** ======================================================================== ***
*   Figure 4: Female Caregiver Norm
*** ======================================================================== ***
if $figure_4{
* Load Country level Data
   use "$data/Final/GenderAtHome_DataCountry.dta", clear 	
	
* Norm 3 by region: PART 1 
** -----------------------------------------------------------------------------
program norm3_part1
if 1{
gl title    "Caregiver Norm: Women's most important role is to take care of her home and children"
gl output_name CountryNorm3_part1

drop if d_higher_pluigno3==0
* Prepare dataset to graph 
gen norm1=est_woman_role_neigh 
gen norm2=d_woman_role_agree
local tosort pluigno3
capt drop i x0
gen x0=0
sort `tosort'
drop if `tosort'==.
gen i=_n
gsort -i

qui des
forvalues j = 1/`r(N)' {
     local o `o' "`=sub_region[`j']'"
}
local j = `r(N)'
foreach o2 of local o {
local ylab `ylab' `j--' "`o2'"
}


* Generate options 
local m1 msiz(3.5pt) mlw(0pt) mc("147 112 219") 
local m2 msiz(3.5pt) mlw(0pt) mc("0 153 153")
local l lw(0.5pt) 


* Twoway graph 
	# d;
	tw pcspike  i norm1  i norm2, `l' lc("0 153 153")                       
				|| scatter i norm1, `m1'                                              
				|| scatter i norm2, `m2'                                              
				||  , legend(order( 2 "Community" 3 "Individual") color("`r(p2)'") 
					  pos(6) size(vsmall) row(1)) ///
					  ylabel(`ylab', labc("`tcol'") angle(0))                       
					  title($title, size(small)  color(dknavy) span pos(11))   
					  subtitle($subtitle, size(vsmall) span pos(11))
					  ytitle("") ylab(, nogrid labc("gs9") labsize (tiny))
					  xlabel(0(5)100,labsize (vsmall)) xlab(,grid)  
					  bgcolor (white) graphregion(color(white));
	# d cr;			  
		  

* Saving and exporting graph
graph save  "$outputs_raw/Figures/Main/${output_name}.gph", replace		
graph export "$outputs_raw/Figures/Main/${output_name}.png", as(png) width(1000) replace  
}
end 
norm3_part1
*  Norm 3 by region: PART 2 
** -----------------------------------------------------------------------------
program norm3_part2
if 1{
* Load Country level Data
  use "$data/Final/GenderAtHome_DataCountry.dta", clear 

gl title    "Caregiver Norm: Women's most important role is to take care of her home and children"
gl output_name CountryNorm3_part2

drop if d_higher_pluigno3==1
* Prepare dataset to graph 
gen norm1=est_woman_role_neigh 
gen norm2=d_woman_role_agree
local tosort pluigno3
capt drop i x0
gen x0=0
sort `tosort'
drop if `tosort'==.
gen i=_n
gsort -i

qui des
forvalues j = 1/`r(N)' {
     local o `o' "`=sub_region[`j']'"
}
local j = `r(N)'
foreach o2 of local o {
local ylab `ylab' `j--' "`o2'"
}


* Generate options 
local m1 msiz(3.5pt) mlw(0pt) mc("147 112 219") 
local m2 msiz(3.5pt) mlw(0pt) mc("0 153 153")
local l lw(0.5pt) 


* Twoway graph 
	# d;
	tw pcspike  i norm1  i norm2, `l' lc("0 153 153")                       
				|| scatter i norm1, `m1'                                              
				|| scatter i norm2, `m2'                                              
				||  , legend(order( 2 "Community" 3 "Individual") color("`r(p2)'") 
					  pos(6) size(vsmall) row(1)) ///
					  ylabel(`ylab', labc("`tcol'") angle(0))                       
					  title($title, size(small)  color(dknavy) span pos(11))   
					  subtitle($subtitle, size(vsmall) span pos(11))
					  ytitle("") ylab(, nogrid labc("gs9") labsize (tiny))
					  xlabel(0(5)100,labsize (vsmall)) xlab(,grid)  
					  bgcolor (white) graphregion(color(white));
	# d cr;			  
		  
	
* Saving and exporting graph
graph save  "$outputs_raw/Figures/Main/${output_name}.gph", replace		
graph export "$outputs_raw/Figures/Main/${output_name}.png", as(png) width(1000) replace 	  			  
}
end
norm3_part2

// Dropping temporary programs
program drop  norm3_part1
program drop  norm3_part2

}
	
	
*** ======================================================================== ***
/// Make sure country temorary dataset is erase
erase  "$data/Final/GenderAtHome_DataCountry.dta"