*** ======================================================================== ***
*             Tables - Regressions labor outcomes and norms 
*** ======================================================================== ***
/* Description: This dofiles replicates tables 2a-c and table 3 which look at
                the correlation of labour outcomes with individual and community
				norms.*/
				
gl table_2   1
gl table_3   1	
	
*** ======================================================================== ***
*   Tables 2a-c
*** ======================================================================== ***				
if $table_2{
** Load Dataset 
   use "$data/Final/GenderAtHome_DataAnalysisInd.dta", clear
   
** Defining globals
 * Outcomes and controls 
   # d;
   gl outcomes1      work_busswage   hhd_rsp_whr_con;
   gl individ        hhd_has_spo 
                     d_age_1 
					 d_age_2  
                     d_hhsize_selfexcluded_2
					 d_hhsize_selfexcluded_3 
					 d_hhsize_selfexcluded_4
					 d_hhsize_selfexcluded_5
				     d_hhd_own_edu_1 
					 d_relation_hhh_2
					 d_relation_hhh_3
					 d_relation_hhh_4
					 d_hhd_urb_1 
					 d_own_land;
   gl demographics   $individ;
   gl region_fe      i.region;
   gl country_fe     i.country_num;					 				 
   # d cr; 
 
 * Set of specifications
   gl xlist1   $demographics   

   gl xlist2a  $xlist1  d_eq_opport_agree  d_eq_opport_agree_fem
   gl xlist2b  $xlist1  eq_opport_neighb   eq_opport_neighb_fem
  
   gl xlist3a  $xlist1 d_expens_agree     d_expens_agree_fem
   gl xlist3b  $xlist1 expens_neigh       expens_neigh_fem
  
   gl xlist4a  $xlist1  d_woman_role_agree  d_woman_role_agree_fem 
   gl xlist4b  $xlist1  woman_role_neigh    woman_role_neigh_fem 

** -----------------------------------------------------------------------------   
*  Labor Outcomes - Correlation with Gender Equality in Opportunities
** -----------------------------------------------------------------------------
if 1{	
	
** Title and output_name: 
   gl H "Table Labor Outcomes - Correlation with Gender Equality in Opportunities Attitudes and Perceived Norms"
   gl output_name "Labor_GenderEquality"
 	
** Regression Code
** -----------------------------------------------------------------------------
   local effect1 d_eq_opport_agree
	gl controls ${xlist2a}
	foreach var in $outcomes1{
	** Reg Code
	eststo: reg  `var'  female_respondent  ${controls}, robust	 

	* Adding up coefficients     
	xi: lincom `effect1'+`effect1'_fem
	local Estimate1 = r(estimate)
	estadd scalar Estimate1 = r(estimate)
	local SE1 = r(se)
	estadd scalar SE1=r(se)
	local tstat1=r(estimate)/r(se)
	local pval1 =r(p)
	estadd scalar pval1=`pval1' 	

	* Saving stats 
	sum    `var' if e(sample) & female_respondent==1 
	estadd scalar mean_var_fem=r(mean) 

	sum    `var' if e(sample) & female_respondent==0 
	estadd scalar mean_var_mal=r(mean) 	   
	estadd local  SAMPLE    "ALL"
	estadd local  COUNTRY_FE "NO"

	** Reg Code Country FE
	eststo: reg  `var'  female_respondent  ${controls} ${country_fe}, robust	 

	* Adding up coefficients     
	xi: lincom `effect1'+`effect1'_fem
	local Estimate1 = r(estimate)
	estadd scalar Estimate1 = r(estimate)
	local SE1 = r(se)
	estadd scalar SE1=r(se)
	local tstat1=r(estimate)/r(se)
	local pval1 =r(p)
	estadd scalar pval1=`pval1' 	

	* Saving stats 
	sum    `var' if e(sample) & female_respondent==1 
	estadd scalar mean_var_fem=r(mean) 

	sum    `var' if e(sample) & female_respondent==0 
	estadd scalar mean_var_mal=r(mean) 	   
	estadd local  SAMPLE    "ALL"
	estadd local  COUNTRY_FE "YES"
			
	   
	}	   
** Regression Code
** -----------------------------------------------------------------------------
   local effect1 eq_opport_neighb
	gl controls ${xlist2b}
	foreach var in $outcomes1{
	** Reg Code
	eststo: reg  `var'  female_respondent  ${controls}, robust	 

	* Adding up coefficients     
	xi: lincom `effect1'+`effect1'_fem
	local Estimate1 = r(estimate)
	estadd scalar Estimate1 = r(estimate)
	local SE1 = r(se)
	estadd scalar SE1=r(se)
	local tstat1=r(estimate)/r(se)
	local pval1 =r(p)
	estadd scalar pval1=`pval1' 	

	* Saving stats 
	sum    `var' if e(sample) & female_respondent==1 
	estadd scalar mean_var_fem=r(mean) 

	sum    `var' if e(sample) & female_respondent==0 
	estadd scalar mean_var_mal=r(mean) 	   
	estadd local  SAMPLE    "ALL"
	estadd local  COUNTRY_FE "NO"

	** Reg Code Country FE
	eststo: reg  `var'  female_respondent  ${controls} ${country_fe}, robust	 

	* Adding up coefficients     
	xi: lincom `effect1'+`effect1'_fem
	local Estimate1 = r(estimate)
	estadd scalar Estimate1 = r(estimate)
	local SE1 = r(se)
	estadd scalar SE1=r(se)
	local tstat1=r(estimate)/r(se)
	local pval1 =r(p)
	estadd scalar pval1=`pval1' 	

	* Saving stats 
	sum    `var' if e(sample) & female_respondent==1 
	estadd scalar mean_var_fem=r(mean) 

	sum    `var' if e(sample) & female_respondent==0 
	estadd scalar mean_var_mal=r(mean) 	   
	estadd local  SAMPLE    "ALL"
	estadd local  COUNTRY_FE "YES"
	
	}	
 
 * Output
   # d;
   esttab using  "$outputs_raw/Tables/Main/$output_name.csv", title("${H}") 
			   stats( N r2 
			          mean_var_fem mean_var_mal  
			          Estimate1 SE1 pval1 
			          SAMPLE COUNTRY_FE, fmt(0 2 2 2 2 2 2 2 2 2 2 2 2 2)       
			   labels( "Observations" 
			           "Adjusted R-squared"        				
					   "Mean Female" 
					   "Mean Male"
					   "Norms+Fem(Coeff)"   "Norms+Fem(SE)" "Norms+Fem(P-value)" 
					   "Sample" 
					   "Country FE"))  
			   drop ($demographics *country_num*)
			   label  brackets plain  numbers depvars
			   star(* 0.1 ** 0.05 *** 0.01)   b(%9.2f) se(%9.2f) replace;
   # d cr;		
	    
* Drop store values	 
  eststo clear		 

** Exporting to unique file 
** ------------------------------------------	
    local svdate: di %tdCCYYNNDD daily("$S_DATE", "DMY")
    disp "`svdate'" 			   
	preserve 
	* Import table from csv
	import delimited "$outputs_raw/Tables/Main/$output_name.csv", ///
	clear delimiter(comma)

	* Exporting into common file 
	export excel using "$outputs_raw/Tables\GenderAtHome_MainTables_`svdate'.xlsx", ///
				 sheet("$output_name", modify) 
	restore   
 
}

** -----------------------------------------------------------------------------   
*  Labor Outcomes - Correlation with Male Breadwinner Norm Attitudes and Perceived
** -----------------------------------------------------------------------------
if 1{	
** Title and output_name: 
   gl H "Table Labor Outcomes and Correlation with Male Breadwinner Norm Attitudes and Perceived"
   gl output_name "Labor_MaleBreadwinner"	
	
** Regression Code
** -----------------------------------------------------------------------------
   local effect1 d_expens_agree 
	gl controls ${xlist3a}
	foreach var in $outcomes1{
	** Reg Code
	eststo: reg  `var'  female_respondent  ${controls}, robust	 

	* Adding up coefficients     
	xi: lincom `effect1'+`effect1'_fem
	local Estimate1 = r(estimate)
	estadd scalar Estimate1 = r(estimate)
	local SE1 = r(se)
	estadd scalar SE1=r(se)
	local tstat1=r(estimate)/r(se)
	local pval1 =r(p)
	estadd scalar pval1=`pval1' 	

	* Saving stats 
	sum    `var' if e(sample) & female_respondent==1 
	estadd scalar mean_var_fem=r(mean) 

	sum    `var' if e(sample) & female_respondent==0 
	estadd scalar mean_var_mal=r(mean) 	   
	estadd local  SAMPLE    "ALL"
	estadd local  COUNTRY_FE "NO"

	** Reg Code Country FE
	eststo: reg  `var'  female_respondent  ${controls} ${country_fe}, robust	 

	* Adding up coefficients     
	xi: lincom `effect1'+`effect1'_fem
	local Estimate1 = r(estimate)
	estadd scalar Estimate1 = r(estimate)
	local SE1 = r(se)
	estadd scalar SE1=r(se)
	local tstat1=r(estimate)/r(se)
	local pval1 =r(p)
	estadd scalar pval1=`pval1' 	

	* Saving stats 
	sum    `var' if e(sample) & female_respondent==1 
	estadd scalar mean_var_fem=r(mean) 

	sum    `var' if e(sample) & female_respondent==0 
	estadd scalar mean_var_mal=r(mean) 	   
	estadd local  SAMPLE    "ALL"
	estadd local  COUNTRY_FE "YES"
	
	
 * Output
   # d;
   esttab using  "$outputs_raw/Tables/Main/$output_name.csv", title("${H}") 
			   stats(N r2 mean_var_fem mean_var_mal  
			   Estimate1 SE1 pval1 
			   SAMPLE COUNTRY_FE, fmt(0 2 2 2 2 2 2 2 2 2 2 2 2 2)       
			   labels( "Observations" "Adjusted R-squared"        				
					   "Mean Female" "Mean Male"
					   "IndNorms+Fem(Coeff)"   "IndNorms+Fem(SE)" "IndNorms+Fem(P-value)" 
					   "ComNorms+Fem(Coeff)"   "ComNorms+Fem(SE)" "ComNorms+Fem(P-value)" 
					   "Sample" "Country FE"))  
			   drop (*country_num*) label  brackets plain  numbers depvars
			   star(* 0.1 ** 0.05 *** 0.01)   b(%9.2f) se(%9.2f) replace;
   # d cr;		
	   
	}
  
** Regression Code
** -----------------------------------------------------------------------------
   local effect1 expens_neigh
	gl controls ${xlist3b}
	foreach var in $outcomes1{
	** Reg Code
	eststo: reg  `var'  female_respondent  ${controls}, robust	 

	* Adding up coefficients     
	xi: lincom `effect1'+`effect1'_fem
	local Estimate1 = r(estimate)
	estadd scalar Estimate1 = r(estimate)
	local SE1 = r(se)
	estadd scalar SE1=r(se)
	local tstat1=r(estimate)/r(se)
	local pval1 =r(p)
	estadd scalar pval1=`pval1' 	

	* Saving stats 
	sum    `var' if e(sample) & female_respondent==1 
	estadd scalar mean_var_fem=r(mean) 

	sum    `var' if e(sample) & female_respondent==0 
	estadd scalar mean_var_mal=r(mean) 	   
	estadd local  SAMPLE    "ALL"
	estadd local  COUNTRY_FE "NO"

	** Reg Code Country FE
	eststo: reg  `var'  female_respondent  ${controls} ${country_fe}, robust	 

	* Adding up coefficients     
	xi: lincom `effect1'+`effect1'_fem
	local Estimate1 = r(estimate)
	estadd scalar Estimate1 = r(estimate)
	local SE1 = r(se)
	estadd scalar SE1=r(se)
	local tstat1=r(estimate)/r(se)
	local pval1 =r(p)
	estadd scalar pval1=`pval1' 	

	* Saving stats 
	sum    `var' if e(sample) & female_respondent==1 
	estadd scalar mean_var_fem=r(mean) 

	sum    `var' if e(sample) & female_respondent==0 
	estadd scalar mean_var_mal=r(mean) 	   
	estadd local  SAMPLE    "ALL"
	estadd local  COUNTRY_FE "YES"
	}
	
 * Output
   # d;
   esttab using  "$outputs_raw/Tables/Main/$output_name.csv", title("${H}") 
			   stats( N r2 
			          mean_var_fem mean_var_mal  
			          Estimate1 SE1 pval1 
			          SAMPLE COUNTRY_FE, fmt(0 2 2 2 2 2 2 2 2 2 2 2 2 2)       
			   labels( "Observations" 
			           "Adjusted R-squared"        				
					   "Mean Female" 
					   "Mean Male"
					   "Norms+Fem(Coeff)"   "Norms+Fem(SE)" "Norms+Fem(P-value)" 
					   "Sample" 
					   "Country FE"))  
			   drop ($demographics *country_num*)
			   label  brackets plain  numbers depvars
			   star(* 0.1 ** 0.05 *** 0.01)   b(%9.2f) se(%9.2f) replace;
   # d cr;		
	    
* Drop store values	 
  eststo clear		 

** Exporting to unique file 
** ------------------------------------------	
    local svdate: di %tdCCYYNNDD daily("$S_DATE", "DMY")
    disp "`svdate'" 			   
	preserve 
	* Import table from csv
	import delimited "$outputs_raw/Tables/Main/$output_name.csv", ///
	clear delimiter(comma)

	* Exporting into common file 
	export excel using "$outputs_raw/Tables\GenderAtHome_MainTables_`svdate'.xlsx", ///
				 sheet("$output_name", modify) 
	restore   
 
}

** -----------------------------------------------------------------------------   
*   Labor Outcomes - Correlation with Female Caregiver
** -----------------------------------------------------------------------------	
if 1{
** Title and output_name: 
   gl H "Table Labor Outcomes and correlation with Female Caregiver Norm Attitudes and Perceived"
   gl output_name "Labor_FemaleCaregiver"	
	
** Regression Code
** -----------------------------------------------------------------------------
   local effect1 d_woman_role_agree
	gl controls ${xlist4a}
	foreach var in $outcomes1{
	** Reg Code
	eststo: reg  `var'  female_respondent  ${controls}, robust	 

	* Adding up coefficients     
	xi: lincom `effect1'+`effect1'_fem
	local Estimate1 = r(estimate)
	estadd scalar Estimate1 = r(estimate)
	local SE1 = r(se)
	estadd scalar SE1=r(se)
	local tstat1=r(estimate)/r(se)
	local pval1 =r(p)
	estadd scalar pval1=`pval1' 	

	* Saving stats 
	sum    `var' if e(sample) & female_respondent==1 
	estadd scalar mean_var_fem=r(mean) 

	sum    `var' if e(sample) & female_respondent==0 
	estadd scalar mean_var_mal=r(mean) 	   
	estadd local  SAMPLE    "ALL"
	estadd local  COUNTRY_FE "NO"

	** Reg Code Country FE
	eststo: reg  `var'  female_respondent  ${controls} ${country_fe}, robust	 

	* Adding up coefficients     
	xi: lincom `effect1'+`effect1'_fem
	local Estimate1 = r(estimate)
	estadd scalar Estimate1 = r(estimate)
	local SE1 = r(se)
	estadd scalar SE1=r(se)
	local tstat1=r(estimate)/r(se)
	local pval1 =r(p)
	estadd scalar pval1=`pval1' 	

	* Saving stats 
	sum    `var' if e(sample) & female_respondent==1 
	estadd scalar mean_var_fem=r(mean) 

	sum    `var' if e(sample) & female_respondent==0 
	estadd scalar mean_var_mal=r(mean) 	   
	estadd local  SAMPLE    "ALL"
	estadd local  COUNTRY_FE "YES"
	
	
 * Output
   # d;
   esttab using  "$outputs_raw/Tables/Main/$output_name.csv", title("${H}") 
			   stats(N r2 mean_var_fem mean_var_mal  
			   Estimate1 SE1 pval1 
			   SAMPLE COUNTRY_FE, fmt(0 2 2 2 2 2 2 2 2 2 2 2 2 2)       
			   labels( "Observations" "Adjusted R-squared"        				
					   "Mean Female" "Mean Male"
					   "IndNorms+Fem(Coeff)"   "IndNorms+Fem(SE)" "IndNorms+Fem(P-value)" 
					   "ComNorms+Fem(Coeff)"   "ComNorms+Fem(SE)" "ComNorms+Fem(P-value)" 
					   "Sample" "Country FE"))  
			   drop (*country_num*) label  brackets plain  numbers depvars   
			   star(* 0.1 ** 0.05 *** 0.01)   b(%9.2f) se(%9.2f) replace;
   # d cr;		
	   
	}
   
		
** Regression Code
** -----------------------------------------------------------------------------
   local effect1 woman_role_neigh
	gl controls ${xlist4b}
	foreach var in $outcomes1{
	** Reg Code
	eststo: reg  `var'  female_respondent  ${controls}, robust	 

	* Adding up coefficients     
	xi: lincom `effect1'+`effect1'_fem
	local Estimate1 = r(estimate)
	estadd scalar Estimate1 = r(estimate)
	local SE1 = r(se)
	estadd scalar SE1=r(se)
	local tstat1=r(estimate)/r(se)
	local pval1 =r(p)
	estadd scalar pval1=`pval1' 	

	* Saving stats 
	sum    `var' if e(sample) & female_respondent==1 
	estadd scalar mean_var_fem=r(mean) 

	sum    `var' if e(sample) & female_respondent==0 
	estadd scalar mean_var_mal=r(mean) 	   
	estadd local  SAMPLE    "ALL"
	estadd local  COUNTRY_FE "NO"

	** Reg Code Country FE
	eststo: reg  `var'  female_respondent  ${controls} ${country_fe}, robust	 

	* Adding up coefficients     
	xi: lincom `effect1'+`effect1'_fem
	local Estimate1 = r(estimate)
	estadd scalar Estimate1 = r(estimate)
	local SE1 = r(se)
	estadd scalar SE1=r(se)
	local tstat1=r(estimate)/r(se)
	local pval1 =r(p)
	estadd scalar pval1=`pval1' 	

	* Saving stats 
	sum    `var' if e(sample) & female_respondent==1 
	estadd scalar mean_var_fem=r(mean) 

	sum    `var' if e(sample) & female_respondent==0 
	estadd scalar mean_var_mal=r(mean) 	   
	estadd local  SAMPLE    "ALL"
	estadd local  COUNTRY_FE "YES"
	}
	
 * Output
   # d;
   esttab using  "$outputs_raw/Tables/Main/$output_name.csv", title("${H}") 
			   stats( N r2 
			          mean_var_fem mean_var_mal  
			          Estimate1 SE1 pval1 
			          SAMPLE COUNTRY_FE, fmt(0 2 2 2 2 2 2 2 2 2 2 2 2 2)       
			   labels( "Observations" 
			           "Adjusted R-squared"        				
					   "Mean Female" 
					   "Mean Male"
					   "Norms+Fem(Coeff)"   "Norms+Fem(SE)" "Norms+Fem(P-value)" 
					   "Sample" 
					   "Country FE"))  
			   drop ($demographics *country_num*)
			   label  brackets plain  numbers depvars
			   star(* 0.1 ** 0.05 *** 0.01)   b(%9.2f) se(%9.2f) replace;
   # d cr;		
	    
* Drop store values	 
  eststo clear		 

** Exporting to unique file 
** ------------------------------------------	
    local svdate: di %tdCCYYNNDD daily("$S_DATE", "DMY")
    disp "`svdate'" 			   
	preserve 
	* Import table from csv
	import delimited "$outputs_raw/Tables/Main/$output_name.csv", ///
	clear delimiter(comma)

	* Exporting into common file 
	export excel using "$outputs_raw/Tables\GenderAtHome_MainTables_`svdate'.xlsx", ///
				 sheet("$output_name", modify) 
	restore   
 
}
}


*** ======================================================================== ***
*   Tables 3
*** ======================================================================== ***
if $table_3{
** Load Dataset 
   use "$data/Final/GenderAtHome_DataAnalysisInd.dta", clear

** Defining globals
 * Outcomes and controls 
   # d;
   gl outcomes1      work_busswage   hhd_rsp_whr_con;
   gl individ        hhd_has_spo 
                     d_age_1 
					 d_age_2  
                     d_hhsize_selfexcluded_2
					 d_hhsize_selfexcluded_3 
					 d_hhsize_selfexcluded_4
					 d_hhsize_selfexcluded_5
				     d_hhd_own_edu_1 
					 d_relation_hhh_2
					 d_relation_hhh_3
					 d_relation_hhh_4
					 d_hhd_urb_1 
					 d_own_land;
   gl demographics   $individ;
   gl region_fe      i.region;
   gl country_fe     i.country_num;					 				 

 * Set of specifications
   gl xlist1  $demographics;   

   gl xlist2c $xlist1  d_eq_opport_agree  d_eq_opport_agree_fem 
                       eq_opport_neighb   eq_opport_neighb_fem; 
					  
   gl xlist3c $xlist1  d_expens_agree     d_expens_agree_fem 
                       expens_neigh       expens_neigh_fem; 
					  
   gl xlist4c $xlist1  d_woman_role_agree  d_woman_role_agree_fem    
                       woman_role_neigh    woman_role_neigh_fem;  
   # d cr; 

** Title and output_name: 
   gl H "Table Labor Outcomes Correlation with Perceived Community Norms, conditional on Personal Beliefs"
   gl output_name "Labor_AllNorms"	
	   
if 1{   
** Regression Code
** -----------------------------------------------------------------------------
   local effect1 d_eq_opport_agree
   local effect2 eq_opport_neighb
   local effect3 eq_opport
	gl controls ${xlist2c}
	foreach var in $outcomes1{
 ** Reg Code Country FE
	eststo: reg  `var'  female_respondent  ${controls} ${country_fe}, robust	 

	* Adding up coefficients     
	xi: lincom `effect1'+`effect1'_fem
	local Estimate1 = r(estimate)
	estadd scalar Estimate1 = r(estimate)
	local SE1 = r(se)
	estadd scalar SE1=r(se)
	local tstat1=r(estimate)/r(se)
	local pval1 =r(p)
	estadd scalar pval1=`pval1' 	

	xi: lincom `effect2'+`effect2'_fem
	local Estimate2 = r(estimate)
	estadd scalar Estimate2 = r(estimate)
	local SE2 = r(se)
	estadd scalar SE2=r(se)
	local tstat2=r(estimate)/r(se)
	local pval2 =r(p)
	estadd scalar pval2=`pval2' 	
	
	estat vif 
	ret li 
	local mean=0.059*(r(vif_1)+r(vif_2)+r(vif_3)+r(vif_4)+r(vif_5)+r(vif_6)+ ///  
	                  r(vif_7)+r(vif_8)+r(vif_9)+r(vif_10)+r(vif_11)+r(vif_12)+ ///
					  r(vif_13)+r(vif_14)+r(vif_15)+r(vif_16)+r(vif_17))	  
	estadd scalar mean_vif=`mean'
	
	
	* Saving stats 
	sum    `var' if e(sample) & female_respondent==1 
	estadd scalar mean_var_fem=r(mean) 

	sum    `var' if e(sample) & female_respondent==0 
	estadd scalar mean_var_mal=r(mean) 	   
	estadd local  SAMPLE    "ALL"
	estadd local  COUNTRY_FE "YES"
	   
	}
     	  
** Regression Code
** -----------------------------------------------------------------------------
   local effect1 d_expens_agree 
   local effect2 expens_neigh	
   local effect3 expens
	gl controls ${xlist3c}
	foreach var in $outcomes1{
 ** Reg Code No Country FE
	eststo: reg  `var'  female_respondent  ${controls} ${country_fe}, robust	 

	* Adding up coefficients     
	xi: lincom `effect1'+`effect1'_fem
	local Estimate1 = r(estimate)
	estadd scalar Estimate1 = r(estimate)
	local SE1 = r(se)
	estadd scalar SE1=r(se)
	local tstat1=r(estimate)/r(se)
	local pval1 =r(p)
	estadd scalar pval1=`pval1' 	

	xi: lincom `effect2'+`effect2'_fem
	local Estimate2 = r(estimate)
	estadd scalar Estimate2 = r(estimate)
	local SE2 = r(se)
	estadd scalar SE2=r(se)
	local tstat2=r(estimate)/r(se)
	local pval2 =r(p)
	estadd scalar pval2=`pval2' 	
	
	estat vif 
	ret li 
	local mean=0.059*(r(vif_1)+r(vif_2)+r(vif_3)+r(vif_4)+r(vif_5)+r(vif_6)+ ///  
	                  r(vif_7)+r(vif_8)+r(vif_9)+r(vif_10)+r(vif_11)+r(vif_12)+ ///
					  r(vif_13)+r(vif_14)+r(vif_15)+r(vif_16)+r(vif_17))	 	  
	estadd scalar mean_vif=`mean'
	
	* Saving stats 
	sum    `var' if e(sample) & female_respondent==1 
	estadd scalar mean_var_fem=r(mean) 

	sum    `var' if e(sample) & female_respondent==0 
	estadd scalar mean_var_mal=r(mean) 	   
	estadd local  SAMPLE    "ALL"
	estadd local  COUNTRY_FE "YES"
	
	}
  
** Regression Code
** -----------------------------------------------------------------------------
   local effect1 d_woman_role_agree 
   local effect2 woman_role_neigh
   local effect3 woman_role
	gl controls ${xlist4c}
	foreach var in $outcomes1{
 ** Reg Code Country FE
	eststo: reg  `var'  female_respondent  ${controls} ${country_fe}, robust	 

	* Adding up coefficients     
	xi: lincom `effect1'+`effect1'_fem
	local Estimate1 = r(estimate)
	estadd scalar Estimate1 = r(estimate)
	local SE1 = r(se)
	estadd scalar SE1=r(se)
	local tstat1=r(estimate)/r(se)
	local pval1 =r(p)
	estadd scalar pval1=`pval1' 	

	xi: lincom `effect2'+`effect2'_fem
	local Estimate2 = r(estimate)
	estadd scalar Estimate2 = r(estimate)
	local SE2 = r(se)
	estadd scalar SE2=r(se)
	local tstat2=r(estimate)/r(se)
	local pval2 =r(p)
	estadd scalar pval2=`pval2' 	
	
	estat vif 
	ret li 
	local mean=0.059*(r(vif_1)+r(vif_2)+r(vif_3)+r(vif_4)+r(vif_5)+r(vif_6)+ ///  
	                  r(vif_7)+r(vif_8)+r(vif_9)+r(vif_10)+r(vif_11)+r(vif_12)+ ///
					  r(vif_13)+r(vif_14)+r(vif_15)+r(vif_16)+r(vif_17))	 	  
	estadd scalar mean_vif=`mean'
	
	
	* Saving stats 
	sum    `var' if e(sample) & female_respondent==1 
	estadd scalar mean_var_fem=r(mean) 

	sum    `var' if e(sample) & female_respondent==0 
	estadd scalar mean_var_mal=r(mean) 	   
	estadd local  SAMPLE    "ALL"
	estadd local  COUNTRY_FE "YES"
	}
	
 * Output
   # d;
   esttab using "$outputs_raw/Tables/Main/$output_name.csv", title("${H}") 
			    stats(N   r2
			         mean_var_fem
					 mean_var_mal  
			         pval1 
			         pval2  		
			         mean_vif
			         SAMPLE COUNTRY_FE, fmt(0 2 2 2 2 2 2 2 2 2 2 2 2 2)       
			    labels("Observations" "Adjusted R-squared"        				
					   "Mean Female" 
					   "Mean Male"
					   "PersBelief+Fem(P-value)" 
					   "ComNorms+Fem(P-value)" 
					   "Mean VIF"
					   "Sample" 
					   "Country FE"))    		   
			   drop ($demographics *country_num*)
			   label  brackets plain  numbers depvars
			   star(* 0.1 ** 0.05 *** 0.01)   b(%9.2f) se(%9.2f) replace;
   # d cr;		
	    
* Drop store values	 
  eststo clear		 

** Exporting to unique file 
** ------------------------------------------	
    local svdate: di %tdCCYYNNDD daily("$S_DATE", "DMY")
    disp "`svdate'" 			   
	preserve 
	* Import table from csv
	import delimited "$outputs_raw/Tables/Main/$output_name.csv", ///
	clear delimiter(comma)

	* Exporting into common file 
	export excel using "$outputs_raw/Tables\GenderAtHome_MainTables_`svdate'.xlsx", ///
				 sheet("$output_name", modify) 
	restore           
}
}

********************************************************************************
// END OF DOFILE