*================================================================= *
*	FACEBOOK DATA												   *
*   PART 2. MERGING WITH OTHER DATASETS              			   *    		
*   2021														   *
*================================================================= *


* Fixing weights 
  gen w1_subregion=w_subregion/100
  la var w1_subregion "Subregion"
* Generating number of female respondents by country so we can restrict analysis 
  bysort sub_region: egen num_resp=count(female_respondent) if female_respondent<.
  bysort sub_region: egen num_females=total(female_respondent)	


*** LEGAL DATASET 
*** -----------------------------------------------------------------
preserve
* Using legal data of last years 
  use  "$data/Intermediate/OtherDatasets/DFID2020_DataClean.dta", clear 
  
* Keeping year 2019 so it matches Facebook data  
  keep if WBLReportYear==2020
* Save dataset 
  isid code_iso3
  codebook code_iso3 
  tempfile datalegal
  save `datalegal'
restore  
  
*** WORLD BANK INDICATORS DATASET
*** -----------------------------------------------------------------
preserve  
	use  "$data/Intermediate/OtherDatasets/WBI_DataClean.dta", clear
	ren countrycode code_iso3
	keep if year==2019	
	tempfile WBI_data
	save `WBI_data'
restore 

* Merging with legal data and WBI data 
   merge m:1 code_iso3 using  `datalegal', nogenerate keep(master matched)
   merge m:1 code_iso3 using  `WBI_data', nogenerate keep(master matched)
  
  encode code_iso3, gen(country_num)
  
  replace region=6 if country_num==53
  replace region=4 if country_num==76
  replace region=2 if country_num==85
  
  
  
  tab region, gen (d_region_)
  des d_region_*
  label var d_region_1  "region: East Asia & Pacific"
  label var d_region_2  "region: Europe & Central Asia"
  label var d_region_3  "region: Latin America & Caribbean"
  label var d_region_4  "region: Middle East & North Africa"
  label var d_region_5  "region: North America"
  label var d_region_6  "region: South Asia"
  label var d_region_7  "region: Sub-Saharan Africa"

  replace region_code=6 if country_num==53
  replace region_code=4 if country_num==76
  replace region_code=2 if country_num==85
  
  
** Merging with Gallup world Data:
** -----------------------------------------------------------------------------  
   merge m:1 code_iso3 using "$data/Intermediate/OtherDatasets/GallupDataBR.dta", ///
   keep(master matched)
   
   gen merge_gallup=(_merge==3)
   drop _merge
   la var merge_gallup "Merge with gallup data"
   
/* We are missing data from Gallup just for 10 countries: 

CHN: China
IRN: Iran
KAZ: Kazakhstan
KOR: Korea, Republic of (South Korea)
LKA: Sri Lanka
NOR: Norway
SEN: Senegal
TZA: Tanzania
UKR: Ukraine
VEN: Venezuela


They are missing data for 76 countries for which we have data
codebook sub_region if _merge==1
*/ 
  