*================================================================= *
*	GENDER AT HOME												   *
*   PART 4. COUNTRY LEVEL DATA				             		   *    		
*   2021														   *
*================================================================= *

* Load Dataset 
use  "$data/Final/GenderAtHome_DataAnalysisInd.dta", clear 
drop if code_iso3==""
drop if d_indchar_sample==0 


gl norms_ind     d_eq_opport_agree d_expens_agree d_woman_role_agree 
gl norms_ind_mn  d_eq_opport_agree_mn d_expens_agree_mn d_woman_role_agree_mn 
gl noms_com      eq_opport_neighb expens_neigh woman_role_neigh 
gl noms_com_est  est_eq_opport_neighb est_woman_role_neigh est_expens_neigh 
gl rank_var      eq_opport expens woman_role

gl female_country perc_fem_*
gl WBI_var        sl_tlf_cact_fe_zs ny_gdp_pcap_cd se_sec_cuat_up_fe_zs
gl WLA            WBLINDEX MOBILITY WORKPLACE PARENTHOOD 

# d; 
gl wvs_norms      C0010-D0780 C0011-D0781 d_D061_??  d_D066_??
                  d_wkgmoth_child? d_womearnsmore?;
				  
gl pl_ind         pl_eq_opport pl_woman_role pl_expens 
                  d_und_a* d_ard_a* d_over_a*;
				  
gl dm_var   self_dm_lp spouse_dm_lp  joint_dm_lp  nopower_dm_lp; 

gl norms_gallup  SupportNational_n1 SupportMen_n1 SupportWomen_n1 
				  BeliefNational_n1 BeliefMen_n1 BeliefWomen_n1
				  MisperceptionaboutMen_n1 MisperceptionaboutWomen_n1;
# d cr;

* Dropping if we can't extrand country level data
drop if code_iso3==""


 * Choosing which variables to keep and labels 
gl collapse_var $noms_com $noms_com_est $norms_ind $norms_ind_mn $wvs_norms ///
                $rank_var $female_country ///
                $WBI_var $WLA $pl_ind $dm_var $norms_gallup region

foreach v of var  $collapse_var{
replace `v'=. if female_respondent==.	
local l`v' : variable label `v'
	if `"`l`v''"' == "" {
	local l`v' "`v'"
 }
}

collapse $collapse_var,   by  (code_iso3 female_respondent)
* Adding labels for formatting before exporting 
  foreach v of var  $collapse_var{
	label var `v' "`l`v''"
	}

 	
	
** Generating daylight at country level 
foreach var of varlist $norms_ind d_und_a* d_ard_a* d_over_a*{
replace `var'=`var'*100
}

foreach var of varlist  $noms_com {
replace `var'=`var'*10
}

sort code_iso3 female_respondent

# d;	

order code_iso3 female_respondent d_eq_opport_agree    d_eq_opport_agree_mn  est_eq_opport_neighb 
 d_expens_agree       d_expens_agree_mn     est_expens_neigh
 d_woman_role_agree   d_woman_role_agree_mn est_woman_role_neigh 
 
 pl_eq_opport   d_und_aeq_opport  d_ard_aeq_opport d_over_aeq_opport
 pl_expens      d_und_aexpens     d_ard_aexpens    d_over_aexpens 
 pl_woman_role  d_und_awoman_role  d_ard_awoman_role d_over_awoman_role;

 br code_iso3 female_respondent d_eq_opport_agree    d_eq_opport_agree_mn  est_eq_opport_neighb 
 d_expens_agree       d_expens_agree_mn     est_expens_neigh
 d_woman_role_agree   d_woman_role_agree_mn est_woman_role_neigh 
 
 pl_eq_opport   d_und_aeq_opport  d_ard_aeq_opport d_over_aeq_opport
 pl_expens      d_und_aexpens     d_ard_aexpens    d_over_aexpens 
 pl_woman_role  d_und_awoman_role  d_ard_awoman_role d_over_awoman_role;
# d cr; 


gen pign_eq_opport=eq_opport_neighb-d_eq_opport_agree 
gen pign_expens=expens_neigh-d_expens_agree
gen pign_woman_role=woman_role_neigh-d_woman_role_agree



foreach var of varlist d_eq_opport_agree d_expens_agree d_woman_role_agree ///
			   eq_opport_neighb expens_neigh woman_role_neigh ///
			   eq_opport expens woman_role pign_* d_und_a* d_ard_a* d_over_a* ///
			   pl_eq_opport pl_woman_role pl_expens ///
			   self_dm_lp spouse_dm_lp  joint_dm_lp  nopower_dm_lp{
gen temp=`var' if female_respondent==1
gen temp2=`var' if female_respondent==0
bysort code_iso3: egen `var'_fem=max(temp)
bysort code_iso3: egen `var'_mal=max(temp2)
drop temp temp2
gen  diff_`var'=`var'_fem-`var'_mal
}






** Labels 
la var eq_opport_neighb   "Community Belief: Men and women should have equal opportunities"
la var expens_neigh       "Community Belief: Expenses are man responsibility, even if wife can help"
la var woman_role_neigh   "Community Belief: Woman's most important role is care of home and child"
la var d_eq_opport_agree  "Individual Belief: (%Agreement) Men and women should have equal opportunities"
la var d_expens_agree     "Individual Belief: (%Agreement) Household expenses are the responsibility of the man"
la var d_woman_role_agree "Individual Belief: (%Agreement) Woman's most important role is care of home and child"
local respondent Female 
local code 1
la var C001`code'   "(`respondent')Jobs scarce: Men should have more right to a job than women"
la var D059`code'   "(`respondent')Men make better political leaders than women do"
la var D060`code'   "(`respondent')University is more important for a boy than for a girl"
la var D063`code'   "(`respondent')Job best way for women to be independent"
la var D066`code'   "(`respondent')Problem if women have more income than husband"
la var D078`code'   "(`respondent')Men make better business executives than women do"
local respondent Male 
local code 0
la var C001`code'   "(`respondent')Jobs scarce: Men should have more right to a job than women"
la var D059`code'   "(`respondent')Men make better political leaders than women do"
la var D060`code'   "(`respondent')University is more important for a boy than for a girl"
la var D063`code'   "(`respondent')Job best way for women to be independent"
la var D066`code'   "(`respondent')Problem if women have more income than husband"
la var D078`code'   "(`respondent')Men make better business executives than women do"
la var perc_fem_work_lastweek  "(%) Females participating labor force"
la var perc_fem_hhd_hed_inc    "(%) Females Breadwinners"
la var perc_fem_self_dm_lp     "(%) Females Solo decision makers large purchases"
la var perc_fem_self_dm_cs     "(%) Females Solo decision makers critical spending"	
la var WBLINDEX    "WB Index"
la var MOBILITY    "Mobility Index"
la var WORKPLACE   "Workplace Index"
la var PARENTHOOD  "Parenthood Index"

//la var diff_d_eq_opport   "Difference Female-Male: Men and women should have equal opportunities(%Agreement)"
//la var diff_d_expens      "Difference Female-Male: Expenses are man responsibility, even if wife can help(%Agreement)"
//la var diff_d_woman_role  "Difference Female-Male: Woman's most important role is care of home and child(%Agreement)" 
la var pign_eq_opport     "Pluralistically ignorance:Men and women should have equal opportunities"
la var pign_expens        "Pluralistically ignorance:Expenses are man responsibility, even if wife can help"
la var pign_woman_role    "Pluralistically ignorance:Woman's most important role is care of home and child"
la var pign_eq_opport_fem    "Women Pluralistically ignorance:Men and women should have equal opportunities"
la var pign_expens_fem       "Women Pluralistically ignorance:Expenses are man responsibility, even if wife can help"
la var pign_woman_role_fem   "Women Pluralistically ignorance:Woman's most important role is care of home and child"
la var pign_eq_opport_mal    "Men Pluralistically ignorance:Men and women should have equal opportunities"
la var pign_expens_mal       "Men Pluralistically ignorance:Expenses are man responsibility, even if wife can help"
la var pign_woman_role_mal   "Men Pluralistically ignorance:Woman's most important role is care of home and child"


* Keeping variable labels 
  # d;
	gl collapse_var   
	              eq_opport_neighb  eq_opport_neighb_fem eq_opport_neighb_mal
				  woman_role_neigh  woman_role_neigh_fem woman_role_neigh_mal
				  expens_neigh      expens_neigh_fem     expens_neigh_mal
				  d_eq_opport_agree d_eq_opport_agree_fem d_eq_opport_agree_mal
				  d_expens_agree    d_expens_agree_fem    d_expens_agree_mal
				  d_woman_role_agree d_woman_role_agree_fem d_woman_role_agree_mal
				  d_*_mn est_*
				  perc_*  pign_* d_D061_??  d_D066_??  d_wkgmoth_child? d_womearnsmore?
				  $WBI_var $WLA D0660 D0661 D0610 D0611 eq_opport expens woman_role
				  eq_opport_fem expens_fem woman_role_fem
				  eq_opport_mal expens_mal woman_role_mal
				  d_und_a* d_ard_a* d_over_a*  pl_*
				  self_dm_lp_* spouse_dm_lp_*  joint_dm_lp_*  nopower_dm_lp_*
				  SupportNational_n1 SupportMen_n1 SupportWomen_n1 
				  BeliefNational_n1 BeliefMen_n1 BeliefWomen_n1
				  MisperceptionaboutMen_n1 MisperceptionaboutWomen_n1;
	# d cr;			
	
	foreach v of var  $collapse_var{
	local l`v' : variable label `v'
		if `"`l`v''"' == "" {
		local l`v' "`v'"
	 }
	}

* Collapsing at the country level no gender
  collapse (max) $collapse_var region, by (code_iso3)

* Adding labels for formatting before exporting 
  foreach v of var  $collapse_var{
	label var `v' "`l`v''"
	}

   gen ln_gdp_usd=ln(ny_gdp_pcap_cd)
   la var ln_gdp_usd "GDP per capita(log USD)"
   
   foreach var of varlist d_D061_?? d_D066_?? d_wkgmoth_child? d_womearnsmore?  ///
   pl_*_mal pl_*_fem{
   replace `var'=`var'*100	
   }
   

   gen pign_eq_opport_country=est_eq_opport_neighb-d_eq_opport_agree 
   gen pign_expens_country=est_expens_neigh-d_expens_agree
   gen pign_woman_role_country=est_woman_role_neigh-d_woman_role_agree
   
	la var pign_eq_opport_country    "Pluralistically ignorance:Men and women should have equal opportunities"
	la var pign_expens_country       "Pluralistically ignorance:Expenses are man responsibility, even if wife can help"
	la var pign_woman_role_country   "Pluralistically ignorance:Woman's most important role is care of home and child"
	la var self_dm_lp_fem    "Female:I have all the power (just me)"
	la var spouse_dm_lp_fem  "Female:Spouse has all the power (just spouse)"
	la var joint_dm_lp_fem   "Female:Joint decision making with spouse"
	la var nopower_dm_lp_fem "Female:No power at all"
	la var self_dm_lp_mal    "Male:I have all the power (just me)"
	la var spouse_dm_lp_mal  "Male:Spouse has all the power (just spouse)"
	la var joint_dm_lp_mal   "Male:Joint decision making with spouse"
	la var nopower_dm_lp_mal "Male:No power at all."

    ren  d_wkgmoth_child0  d_wkgmoth_child_mal
    ren  d_wkgmoth_child1  d_wkgmoth_child_fem
    ren  d_womearnsmore0   d_womearnsmore_mal
    ren  d_womearnsmore1   d_womearnsmore_fem

   gen diff_wkgmoth_child=d_wkgmoth_child_mal-d_wkgmoth_child_fem
   gen diff_womenearnsmore=d_womearnsmore_mal-d_womearnsmore_fem
   gen diff_d_eq_opport_agree=d_eq_opport_agree_mal-d_eq_opport_agree_fem
   gen diff_d_expens_agree=d_expens_agree_mal-d_expens_agree_fem
   gen diff_d_woman_role_agree=d_woman_role_agree_mal-d_woman_role_agree_fem

    foreach var of varlist d_eq_opport_agree  d_expens_agree d_woman_role_agree{
   replace `var'=`var'/10	
   }
     
   foreach var of varlist  eq_opport_neighb_fem eq_opport_neighb_mal ///
	                        expens_neigh_fem expens_neigh_mal         ///
							woman_role_neigh_fem woman_role_neigh_mal{
    replace `var'=`var'*10	
   }
  
  

  
 ** Generating quintiles using breadwinner and care taker role   
    xtile q_eq_opport_agree  = d_eq_opport_agree , nq(10)
    xtile q_expens_agree = d_expens_agree, nq(10)  
    xtile q_woman_role_agree = d_woman_role_agree, nq(10) 
	
	gen    gallup_sample=(SupportNational_n1<.)
    la var gallup_sample "Gallup Sample"
	
** Generating differences with representative sample 
   gen diff_support=d_eq_opport_agree_mn-SupportNational_n1
   gen diff_supportwom=d_eq_opport_agree_fem-SupportWomen_n1
   gen diff_supportmen=d_eq_opport_agree_mal-SupportMen_n1
   gen diff_belief=est_eq_opport_neighb-BeliefNational_n1 
   gen diff_beliefwom=eq_opport_neighb_fem-BeliefWomen_n1 
   gen diff_beliefmen=eq_opport_neighb_mal-BeliefMen_n1
   
   
* Labels    
   la var d_eq_opport_agree_mn  "Facebook Data:Support National (%)"
   la var d_eq_opport_agree_fem "Facebook Data:Support Women (%)"
   la var d_eq_opport_agree_mal "Facebook Data:Support Men (%)"  
   la var est_eq_opport_neighb  "Facebook Data:Belief about support National (%)"
   la var eq_opport_neighb_fem  "Facebook Data:Belief about support Women (%)"
   la var eq_opport_neighb_mal  "Facebook Data:Belief about support Men (%)"
   
   la var SupportNational_n1 	"Gallup Data:Support National (%)"
   la var SupportWomen_n1    	"Gallup Data:Support Women (%)"
   la var SupportMen_n1 		"Gallup Data:Support Men (%)"  
   la var BeliefNational_n1  	"Gallup Data:Belief about support National (%)"
   la var BeliefWomen_n1  		"Gallup Data:Belief about support Women (%)"
   la var BeliefMen_n1 			"Gallup Data:Belief about support Men (%)"   
   
   la var diff_support         "Support National Difference (Facebook-Gallup)"
   la var diff_supportmen      "Support Men Difference (Facebook-Gallup)" 
   la var diff_supportwom      "Support Women Difference (Facebook-Gallup)" 
   la var diff_belief          "Belief  National Difference (Facebook-Gallup)" 
   la var diff_beliefwom       "Belief  Women Difference (Facebook-Gallup)" 
   la var diff_beliefmen       "Belief  Men  Difference (Facebook-Gallup)" 
   
   
   la val region regions 
   
   
 ** Gallup pluralistic ignorance 
    gen pign_support=BeliefNational_n1-SupportNational_n1
	gen pign_supportwom=BeliefWomen_n1-SupportWomen_n1 
    gen pign_supportmen=BeliefMen_n1-SupportMen_n1 
    la var  pign_support    "Gallup Data:Misperception National"  
    la var  pign_supportwom "Gallup Data:Misperception Women"  
    la var  pign_supportmen "Gallup Data:Misperception Men"  	
	
 ** Facebook pluralistic ignorance 
    gen pign_eq_opport2=est_eq_opport_neighb-d_eq_opport_agree_mn
	gen pign_eq_opportwom2=eq_opport_neighb_fem-d_eq_opport_agree_mn
	gen pign_eq_opportmen2=eq_opport_neighb_mal-d_eq_opport_agree_mn
	
	gen pign_expens2=est_expens_neigh-d_expens_agree_mn
	gen pign_expenswom2=expens_neigh_fem-d_expens_agree_mn   
	gen pign_expensmen2=expens_neigh_mal-d_expens_agree_mn
				 
	gen pign_womanr2=est_woman_role_neigh-d_woman_role_agree_mn
	gen pign_womanrwom2=woman_role_neigh_fem-d_woman_role_agree_mn    
	gen pign_womanrmen2=woman_role_neigh_mal-d_woman_role_agree_mn
						 
   la var d_eq_opport_agree_mn    "Aggregate individual belief(National):Men and women should have equal opportunities"
   la var d_eq_opport_agree_fem   "Aggregate individual belief(Women):Men and women should have equal opportunities"
   la var d_eq_opport_agree_mal   "Aggregate individual belief(Men):Men and women should have equal opportunities"
   la var est_eq_opport_neighb    "Community perceived beliefs(National):Men and women should have equal opportunities"
   la var eq_opport_neighb_fem    "Community perceived beliefs(Women):Men and women should have equal opportunities"
   la var eq_opport_neighb_mal    "Community perceived beliefs(Men):Men and women should have equal opportunities"
   la var pign_eq_opport2         "Misperception(National):Men and women should have equal opportunities"
   la var pign_eq_opportwom2      "Misperception(Women):Men and women should have equal opportunities"
   la var pign_eq_opportmen2      "Misperception(Men):Men and women should have equal opportunities"  
   
   la var d_expens_agree_mn       "Aggregate individual belief(National):Household expenses are the responsibility of the man, even if his wife can help him"
   la var d_expens_agree_fem      "Aggregate individual belief(Women):Household expenses are the responsibility of the man, even if his wife can help him"
   la var d_expens_agree_mal      "Aggregate individual belief(Men):Household expenses are the responsibility of the man, even if his wife can help him"
   la var est_expens_neigh        "Community perceived beliefs(National):Household expenses are the responsibility of the man, even if his wife can help him"
   la var expens_neigh_fem        "Community perceived beliefs(Women):Household expenses are the responsibility of the man, even if his wife can help him"
   la var expens_neigh_mal        "Community perceived beliefs(Men):Household expenses are the responsibility of the man, even if his wife can help him"
	la var pign_expens2           "Misperception(National):Household expenses are the responsibility of the man, even if his wife can help him"
	la var pign_expenswom2        "Misperception(Women):Household expenses are the responsibility of the man, even if his wife can help him"
	la var pign_expensmen2        "Misperception(Men):Household expenses are the responsibility of the man, even if his wife can help him"
	
   la var d_woman_role_agree_mn   "Aggregate individual belief(National):A woman's most important role is to take care of her home and children"
   la var d_woman_role_agree_fem  "Aggregate individual belief(Women):A woman's most important role is to take care of her home and children"
   la var d_woman_role_agree_mal  "Aggregate individual belief(Men):A woman's most important role is to take care of her home and children"
   la var est_woman_role_neigh    "Community perceived beliefs(National):A woman's most important role is to take care of her home and children"
   la var woman_role_neigh_fem    "Community perceived beliefs(Women):A woman's most important role is to take care of her home and children"
   la var woman_role_neigh_mal    "Community perceived beliefs(Men):A woman's most important role is to take care of her home and children"
   la var pign_womanr2            "Misperception(National):Woman's most important role is care of home and children"
   la var pign_womanrwom2         "Misperception(Women):Woman's most important role is care of home and children"	
   la var pign_womanrmen2         "Misperception(Men):Woman's most important role is care of home and children"

   
* Generating a difference 
  gen diff_femcare_fem=D0611-woman_role_fem
  gen diff_femcare_mal=D0610-woman_role_mal
 
  gen diff_malbred_fem=D0661-expens_fem
  gen diff_malbred_mal=D0660-expens_mal  

    
  egen     wvs_merge_temp=rowmiss(D0610 D0611 D0660 D0661)
  gen      wvs_merge=(wvs_merge_temp==0 | wvs_merge_temp==2)
  la var   wvs_merge "Countries merged Gender At Home and WVS"
  drop     wvs_merge_temp
   
  la var woman_role_fem   "Woman's most important role is to take care of home and children (Female)"
  la var woman_role_mal   "Woman's most important role is to take care of home and children (Male)"
  la var D0611            "Pre-school child suffers with working mother (Female)"
  la var D0610            "Pre-school child suffers with working mother (Male)"

  la var expens_fem       "Household expenses are the responsibility of a man even if his wife can help him (Female)"
  la var expens_mal       "Household expenses are the responsibility of a man even if his wife can help him (Male)"

  la var D0661            "If a woman earns more money than her husband, it's almost certain to cause problems(Female)"
  la var D0660            "If a woman earns more money than her husband, it's almost certain to cause problems(Male)"
  la var diff_femcare_fem "Female Caregiver: Difference in rank (Female)"
  la var diff_femcare_mal "Female Caregiver: Difference in rank (Male)"
  la var diff_malbred_fem "Male Breadwinner Norm: Difference in rank (Female)"
  la var diff_malbred_mal "Male Breadwinner Norm: Difference in rank (Male)"
   
** Differecens 				 
   gen    diff_pign= pign_eq_opport2-pign_support
   la var diff_pign "Misperception National Difference (Facebook-Gallup)"
   gen    diff_pignwom=pign_eq_opportwom2-pign_supportwom
   la var diff_pignwom "Misperception Women Difference (Facebook-Gallup)"
   gen    diff_pignmen=pign_eq_opportmen2-pign_supportmen
   la var diff_pignmen "Misperception Men Difference (Facebook-Gallup)"
         
* Defining quintiles  
  sort ln_gdp_usd
  xtile gdp4=ln_gdp_usd, nq(4)
  
  sort  sl_tlf_cact_fe_zs
  gen LFP4=. 
  replace LFP4=1 if (sl_tlf_cact_fe_zs>10 & sl_tlf_cact_fe_zs<30)
  replace LFP4=2 if (sl_tlf_cact_fe_zs>29 & sl_tlf_cact_fe_zs<50)  
  replace LFP4=3 if (sl_tlf_cact_fe_zs>49 & sl_tlf_cact_fe_zs<70)  
  replace LFP4=4 if (sl_tlf_cact_fe_zs>69 & sl_tlf_cact_fe_zs<90)

  sort  WBLINDEX
  xtile WBLINDEX4=WBLINDEX, nq(4)	   
   