* **************************************************************************** *
* **************************************************************************** *
* Breadwinners and Caregivers: Examining the Global Relationship between       *
* Gender Norms and Economic Behavior                                           *
* Replication File                                                             *
* 2024                                                                         *
* **************************************************************************** *
* **************************************************************************** *

/*
* Author: Paula Gonzalez
* Program Purpose: This master dofile runs all necessary dofiles to reproduce
*                  the analysis presented in the paper 
*                  "Breadwinners and Caregivers: Examining the Global Relationship 
*                   between Gender Norms and Economic Behavior". 
* Date last time review: February 2024
*------------------------------------------------------------------------------*
* Datasets Required: [List the required datasets here, if applicable]
*
* Unique Identificator: [Specify if there's any unique identifier for the datasets]
*
* Outline: 
*  Part 1. Data Cleaning and Preparation 
*  Part 2. Constructing Data Variables for Analysis 
*  Part 3. Data Analysis - Reproducing Descriptive Statistics, Regression 
*          Tables, and Graphs as included in the final draft.
*/

********************************************************************************
*                       PREPARATION AND MAIN SETTINGS 
********************************************************************************


if 1{
	

* ------------------------------------------------------------------------------
* Standardize Settings Across Users:
* ------------------------------------------------------------------------------
  ieboilstart, version(12.1) matsize(11000)
  `r(version)'   
  //set abbrev on
  
* ------------------------------------------------------------------------------
* Root Folder Globals - Define User and Paths:
* ------------------------------------------------------------------------------
   if 1{
      
   * Assign User Number (Add more users as needed):
   * 1 - Paula
   * 2 - Sree
   * 3 - Other 

   * Set the user number for the current session:
    gl user  2

   * Define OneDrive Paths for Each User:
   * ------------------------------------
   if $user == 1 {
       gl onedrive "C:\Users\wb448687\OneDrive - WBG\Gender Equality at Home"
   }
   if $user == 2 {
       gl onedrive "C:\Users\wb614536\OneDrive - WBG\Documents\Reproducibility\RR_WLD_2024_86\files submitted\version2"
   }
   
   
   
   
   
   * Define Project Folder Globals:
   * -------------------------------
     local main_folder ReplicationPackage_BreadwinnersAndCaregivers
     gl data          "$onedrive/`main_folder'/Data"
     gl dofiles       "$onedrive/`main_folder'/Dofiles"
     gl outputs_raw   "$onedrive/`main_folder'/Outputs/Raw" 
     gl outputs_final "$onedrive/`main_folder'/Outputs/Final" 
}   


  * Define ado folder:
   * -------------------------------
   
   sysdir set PLUS "$dofiles/ado"
   
   * ------------------------------------------------------------------------------
* Install Required Packages (Activate this section for first-time setup):
* ------------------------------------------------------------------------------
if 0{
   ssc install ietoolkit, replace
   ssc install outreg2, replace
   ssc install estout, replace
   ssc install spmap, replace
   ssc install shp2dta, replace
   ssc install coefplot, replace
   ssc install schemepack, replace 
   ssc install colrspace, replace 
   
}

* ------------------------------------------------------------------------------
*  Define Sections to Execute:
* ------------------------------------------------------------------------------
   local paper_name "BreadwinnersAndCaregivers"   
   local DataCleanig     0    /*This part should not be activate form outside the 
                              people authorized to use the raw dataset from 
							  Gender at home.*/
   local DataConstruction 1
   local DataAnalysis     1    
}   
  

********************************************************************************
*                    DATA PREPARATION AND CLEANING
******************************************************************************** 
* if (`DataCleaning' == 1) { 
*  do "$dofiles/Cleaning/Part1_MasterDataCleaning.do"
* }
  
  
  
********************************************************************************
*                    DATA VARIABLE CONSTRUCTION 
******************************************************************************** 
if (`DataConstruction' == 1) { 
   do "$dofiles/Intermediate/Part2_MasterDataConstruction.do"
}

********************************************************************************
*                    DATA ANALYSIS 
******************************************************************************** 
if (`DataAnalysis' == 1) { 
   do "$dofiles/Analysis/Part3_MasterDataAnalysis.do"
}


********************************************************************************
// END OF MASTER DOFILE